@@ -4,41 +4,51 @@ Basic for handler
 '''
 
 import socket
+import time
 
 import tornado.web
 from tornado.concurrent import run_on_executor
-
-from config import kind_arr, post_type
 from torcms.core.tool import run_whoosh
 from torcms.model.user_model import MUser
 
+from config import kind_arr, post_type
+from config import CMS_CFG
+
 
 class BaseHandler(tornado.web.RequestHandler):
     '''
     The base class for handlers.
+    继承RequestHandler，并添加了一些自定义的函数，方便使用。
     '''
+
     def initialize(self, **kwargs):
-
-        # self.set_cookie('b_locale', 'zh_CN')
-        # self.set_cookie('b_locale', 'en')
-
+        '''
+        Tornado 的初始化方法
+        '''
         _ = kwargs
         super().initialize()
         if self.get_current_user():
             self.userinfo = MUser.get_by_name(self.get_current_user())
+            if self.userinfo:
+                self.set_secure_cookie(
+                    "user",
+                    self.userinfo.user_name,
+                    expires_days=None,
+                    expires=time.time() + 60 * CMS_CFG.get('expires_minutes', 15)
+                )
         else:
             self.userinfo = None
         self.is_p = False  # True, if partially rendered.
         self.is_j = False  # True, if json would be returned.
 
-    def get_post_data(self):
+    def get_request_arguments(self):
         '''
-        Get all the arguments from post request. Only get the first argument by default.
+        Get all the arguments from request. Only get the first argument by default.
         '''
-        post_data = {}
+        para_dict = {}
         for key in self.request.arguments:
-            post_data[key] = self.get_arguments(key)[0]
-        return post_data
+            para_dict[key] = self.get_arguments(key)[0]
+        return para_dict
 
     # pylint: disable=R0201
     def parse_url(self, url_str):
@@ -76,9 +86,6 @@ class BaseHandler(tornado.web.RequestHandler):
         the current user.
         '''
         return self.get_secure_cookie("user")
-        # user_id = self.get_secure_cookie("user")
-        # if not user_id: return None
-        #     return self.backend.get_user_by_id(user_id)
 
     def get_user_locale(self):
         '''
@@ -87,30 +94,30 @@ class BaseHandler(tornado.web.RequestHandler):
         locale_id = self.get_cookie('ulocale')
         if locale_id:
             return tornado.locale.get(locale_id)
-        else:
-            return tornado.locale.get('en_US')
 
-    def get_browser_locale(self):
-        '''
-        Override the function, to control the UI language.
-        '''
-        locale_id = self.get_cookie('blocale')
-        if locale_id:
-            return tornado.locale.get(locale_id)
-        else:
-            return tornado.locale.get('en_US')
+        return tornado.locale.get('en_US')
+
+    # def get_browser_locale(self, default: str = "en_US"):
+    #     '''
+    #     Override the function, to control the UI language.
+    #     '''
+    #     locale_id = self.get_cookie('blocale')
+    #     if locale_id:
+    #         return tornado.locale.get(locale_id)
+    #
+    #     return tornado.locale.get('en_US')
 
     def is_admin(self):
         '''
         if is admin
         '''
-        return True if self.check_post_role()['ADMIN'] else False
+        return self.check_post_role()['ADMIN']
 
     def editable(self):
         '''
         if is editable
         '''
-        return True if self.check_post_role()['EDIT'] else False
+        return self.check_post_role()['EDIT']
 
     def data_received(self, chunk):
         return False
@@ -122,29 +129,24 @@ class BaseHandler(tornado.web.RequestHandler):
         '''
         run_whoosh.gen_whoosh_database(kind_arr=kind_arr, post_type=post_type)
 
-    def wrap_tmpl(self, tmpl):
-        '''
-        return the warpped template path.
-        :param tmpl:
-        '''
-        return 'admin/' + tmpl.format(sig='p') if self.is_p else tmpl.format(
-            sig='')
-
     def get_host_ip(self):
         """
         查询本机ip地址
-        :return:
         """
+        socker = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         try:
-            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-            s.connect(('8.8.8.8', 80))
-            ip = s.getsockname()[0]
+            socker.connect(('8.8.8.8', 80))
+            local_ip = socker.getsockname()[0]
+        except Exception:
+            local_ip = '0.0.0.0'
         finally:
-            s.close()
-
-        return ip
+            socker.close()
+        return local_ip
 
     def show404(self, kwd=None):
+        '''
+        Show 404 Page.
+        '''
         if kwd:
             pass
         else:
