@@ -10,10 +10,10 @@ def is_prived(usr_rule, def_rule):
     '''
     Compare between two role string.
     '''
-    for iii in range(4):
-        if def_rule[iii] == '0':
+    for ii in range(4):
+        if def_rule[ii] == '0':
             continue
-        if usr_rule[iii] >= def_rule[iii]:
+        if usr_rule[ii] >= def_rule[ii]:
             return True
 
     return False
@@ -23,14 +23,15 @@ def auth_view(method):
     '''
     role for view.
     '''
+
     def wrapper(self, *args, **kwargs):
         '''
         wrapper.
         '''
-
         if ROLE_CFG['view'] == '':
-            return method(self, *args, **kwargs)
+            pass
         elif self.current_user:
+
             if is_prived(self.userinfo.role, ROLE_CFG['view']):
                 return method(self, *args, **kwargs)
             else:
@@ -47,6 +48,8 @@ def auth_view(method):
             }
             self.render('misc/html/404.html', kwd=kwd, userinfo=self.userinfo)
 
+        return method(self, *args, **kwargs)
+
     return wrapper
 
 
@@ -54,6 +57,7 @@ def auth_add(method):
     '''
     role for add.
     '''
+
     def wrapper(self, *args, **kwargs):
         '''
         wrapper.
@@ -82,6 +86,7 @@ def auth_edit(method):
     '''
     role for edit.
     '''
+
     def wrapper(self, *args, **kwargs):
         '''
         wrapper.
@@ -111,12 +116,12 @@ def auth_delete(method):
     '''
     role for delete.
     '''
+
     def wrapper(self, *args, **kwargs):
         '''
         wrapper.
         '''
         if self.current_user:
-
             if is_prived(self.userinfo.role, ROLE_CFG['delete']):
                 return method(self, *args, **kwargs)
             else:
@@ -140,12 +145,12 @@ def auth_admin(method):
     '''
     role for admin.
     '''
+
     def wrapper(self, *args, **kwargs):
         '''
         wrapper.
         '''
         if self.current_user:
-
             if is_prived(self.userinfo.role, ROLE_CFG['admin']):
                 return method(self, *args, **kwargs)
             else:
@@ -155,6 +160,34 @@ def auth_admin(method):
                 self.render('misc/html/404.html',
                             kwd=kwd,
                             userinfo=self.userinfo)
+        else:
+            kwd = {
+                'info': 'No role',
+            }
+            self.render('misc/html/404.html', kwd=kwd, userinfo=self.userinfo)
+
+    return wrapper
+
+
+def auth_check(method):
+    '''
+    role for examine.
+    '''
+
+    def wrapper(self, *args, **kwargs):
+        '''
+        wrapper.
+        '''
+        if self.current_user:
+            if is_prived(self.userinfo.role, ROLE_CFG['check']):
+                return method(self, *args, **kwargs)
+            else:
+                kwd = {
+                    'info': 'No role',
+                }
+                self.render('misc/html/404.html',
+                            kwd=kwd,
+                            userinfo=self.userinfo)
 
         else:
             kwd = {
