@@ -33,55 +33,55 @@ from torcms.handlers.user_handler import UserHandler, UserPartialHandler
 from torcms.handlers.user_info_list_handler import UserListHandler
 from torcms.handlers.wiki_handler import WikiHandler
 from torcms.handlers.wiki_history_manager import WikiHistoryHandler
+from torcms.handlers.check_handler import CheckHandler
 
 urls = [
-    ('/_rating/(.*)', RatingHandler, dict()),
-    ('/post_man/(.*)', PostHistoryHandler, dict()),
-    ('/meta_man/(.*)', PostHistoryHandler, dict()),
-    ('/wiki_man/(.*)', WikiHistoryHandler, dict()),
-    ('/page_man/(.*)', WikiHistoryHandler, dict()),
-    ("/admin/(.*)", AdminHandler, dict()),
-    ("/entry/(.*)", EntityHandler, dict()),
-    ("/entity/(.*)", EntityHandler, dict()),
-    ("/entity_j/(.*)", EntityAjaxHandler, dict()),
-    ("/entity_download/(.*)", Entity2UserHandler, dict()),
+    ('/_rating/(.*)', RatingHandler, {}),
+    ('/post_man/(.*)', PostHistoryHandler, {}),
+    ('/meta_man/(.*)', PostHistoryHandler, {}),
+    ('/wiki_man/(.*)', WikiHistoryHandler, {}),
+    ('/page_man/(.*)', WikiHistoryHandler, {}),
+    ("/admin/(.*)", AdminHandler, {}),
+    ("/entry/(.*)", EntityHandler, {}),
+    ("/entity/(.*)", EntityHandler, {}),
+    ("/entity_j/(.*)", EntityAjaxHandler, {}),
+    ("/entity_download/(.*)", Entity2UserHandler, {}),
 
     # For listing items.
-
-    # ToDo: To check.
-    ("/list/(.*)", ListHandler, dict()),  # use to be category
+    ("/list/(.*)", ListHandler, {}),
     ("/post/(.*)", PostHandler, dict(kind='1')),
 
     # For listing ordered items.
-    ("/catalog/(.*)", CatalogHandler, dict()),
+    ("/catalog/(.*)", CatalogHandler, {}),
     ("/leaf/(.*)", LeafHandler, dict(kind='6')),
 
     # For filter listing.
-    ("/filter/(.*)", FilterHandler, dict()),
+    ("/filter/(.*)", FilterHandler, {}),
     ("/info/(.*)", PostHandler, dict(kind='9', filter_view=True)),
-    ("/label/(.*)", LabelHandler, dict()),
-    ("/user/(.*)", UserHandler, dict()),
-    ("/user_j/(.*)", UserPartialHandler, dict()),
-    ("/post_j/(.*)", PostAjaxHandler, dict()),
-    ("/post_list/(.*)", PostListHandler, dict()),
-    ("/category_j/(.*)", CategoryAjaxHandler, dict()),
-    ("/link_j/(.*)", LinkPartialHandler, dict()),
-    ("/link/(.*)", LinkHandler, dict()),
-    ("/page_j/(.*)", PageAjaxHandler, dict()),
-    ("/page/(.*)", PageHandler, dict()),
-    ("/wiki/(.*)", WikiHandler, dict()),
-    ("/search/(.*)", SearchHandler, dict()),
-    ("/reply/(.*)", ReplyHandler, dict()),
-    ("/publish/(.*)", PublishHandler, dict()),
-    ("/collect/(.*)", CollectHandler, dict()),
-    ('/rel/(.*)', RelHandler, dict()),
-    ("/user_list/(.*)", UserListHandler, dict()),
-    ("/evaluate/(.*)", EvaluationHandler, dict()),
-    ("/sys/(.*)", SysHandler, dict()),
-    ("/log/(.*)", LogHandler, dict()),
-    ("/log_j/(.*)", LogPartialHandler, dict()),
-    ('/nullify_info/(.*)', NullifyInfoHandler, dict()),
-    ('/comment/(.*)', CommentHandler, dict()),
-    ('/classify/(.*)', ClassifyHandler, dict()),
-    ("/", IndexHandler, dict())
+    ("/label/(.*)", LabelHandler, {}),
+    ("/user/(.*)", UserHandler, {}),
+    ("/user_j/(.*)", UserPartialHandler, {}),
+    ("/post_j/(.*)", PostAjaxHandler, {}),
+    ("/post_list/(.*)", PostListHandler, {}),
+    ("/category_j/(.*)", CategoryAjaxHandler, {}),
+    ("/link_j/(.*)", LinkPartialHandler, {}),
+    ("/link/(.*)", LinkHandler, {}),
+    ("/page_j/(.*)", PageAjaxHandler, {}),
+    ("/page/(.*)", PageHandler, {}),
+    ("/wiki/(.*)", WikiHandler, {}),
+    ("/search/(.*)", SearchHandler, {}),
+    ("/reply/(.*)", ReplyHandler, {}),
+    ("/publish/(.*)", PublishHandler, {}),
+    ("/collect/(.*)", CollectHandler, {}),
+    ('/rel/(.*)', RelHandler, {}),
+    ("/user_list/(.*)", UserListHandler, {}),
+    ("/evaluate/(.*)", EvaluationHandler, {}),
+    ("/sys/(.*)", SysHandler, {}),
+    ("/log/(.*)", LogHandler, {}),
+    ("/log_j/(.*)", LogPartialHandler, {}),
+    ('/nullify_info/(.*)', NullifyInfoHandler, {}),
+    ('/comment/(.*)', CommentHandler, {}),
+    ('/classify/(.*)', ClassifyHandler, {}),
+    ("/check/(.*)", CheckHandler, dict()),
+    ("/", IndexHandler, {})
 ]
