@@ -18,17 +18,7 @@ from markdown.extensions.wikilinks import WikiLinkExtension
 from playhouse.postgres_ext import PostgresqlExtDatabase
 
 import cfg
-from torcms.core.libs.deprecation import deprecated
 
-# try:
-#     from jieba.analyse import ChineseAnalyzer
-# except:
-#     ChineseAnalyzer = None
-# from whoosh.analysis import StemmingAnalyzer
-
-# import config
-
-# Config for logging
 logging.basicConfig(
     level=logging.DEBUG,
     format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
@@ -55,40 +45,11 @@ def html_min(func):
     '''
 
     def wrapper(*args):
-        # return html_minify(func(*args))
         return minify(func(*args))
 
     return wrapper
 
 
-class Storage(dict):
-    """
-    from web.py
-    对字典进行扩展，使其支持通过 dict.a形式访问以代替dict['a']
-    """
-
-    def __getattr__(self, key):
-        try:
-            return self[key]
-        except KeyError:
-            raise AttributeError
-
-    def __setattr__(self, key, value):
-        self[key] = value
-
-    def __delattr__(self, key):
-        try:
-            del self[key]
-        except KeyError:
-            raise AttributeError
-
-    def __repr__(self):
-        return '<Storage ' + dict.__repr__(self) + '>'
-
-
-storage = Storage
-
-
 def diff_table(rawinfo, newinfo):
     '''
     Generate the difference as the table format.
@@ -139,6 +100,19 @@ def check_email_valid(email_str):
     return False
 
 
+def check_pass_valid(pass_str):
+    '''
+    Checking if the given password is valid.
+    至少6-20个字符，至少1个大写字母，1个小写字母和1个数字，其他可以是任意字符
+    '''
+
+    ck_str = "^(?=.*[A-Za-z])(?=.*\d)[A-Za-z\d][\s\S]{6,20}$"
+    if re.match(ck_str, pass_str) is not None:
+        return True
+
+    return False
+
+
 def md5(instr):
     '''
     md5
@@ -170,7 +144,6 @@ def format_date(indate):
 def get_uuid():
     '''
     Using python uuid
-    :return:
     '''
     return str(uuid.uuid1())
 
@@ -179,53 +152,57 @@ def get_uu8d():
     '''
     Get ID of 8 digit.
     '''
-    return str(uuid.uuid1()).split('-')[0]
+
+    # str(uuid.uuid1()).split('-', maxsplit=1)[0]
+    return str(uuid.uuid1()).split('-', maxsplit=1)[0]
 
 
-def func_rand_arr(arr, len):
+def func_rand_arr(arr, length):
     '''
     func_rand_arr = lambda arr, len: ''.join(random.sample(arr, len))
     '''
-    return ''.join(random.sample(arr, len))
+    return ''.join(random.sample(arr, length))
 
 
 def get_uu4d_v2():
     '''
     Get ID of 4 digit. version 2.
     '''
-    sel_arr = [x for x in 'ghijklmnopqrstuvwxyz']
-    return func_rand_arr(sel_arr, 4)
+    # sel_arr = [x for x in 'ghijklmnopqrstuvwxyz']
+
+    return func_rand_arr(
+        list('ghijklmnopqrstuvwxyz'),
+        4
+    )
 
 
 def get_uu4d():
     '''
     Get ID of 4 digit.
     '''
-    sel_arr = [
-        '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd',
-        'e', 'f'
-    ]
-    # rarr = random.sample(sel_arr, 4)
-    return func_rand_arr(sel_arr, 4)
+
+    return func_rand_arr(
+        list('0123456789abcdef'),
+        4
+    )
 
 
 def get_uu5d():
     '''
     Get ID of 5 digit.
     '''
-    sel_arr = [
-        '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd',
-        'e', 'f'
-    ]
-    # rarr = random.sample(sel_arr, 5)
-    return func_rand_arr(sel_arr, 5)
+
+    return func_rand_arr(
+        list('0123456789abcdef'),
+        5
+    )
 
 
 def get_uudd(lenth):
     '''
     随机获取给定位数的整数
     '''
-    sel_arr = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']
+    sel_arr = list('0123456789')
     rarr = random.sample(sel_arr, lenth)
     while rarr[0] == '0':
         rarr = random.sample(sel_arr, lenth)
@@ -236,11 +213,11 @@ def get_uu6d():
     '''
     Get ID of 6 digit.
     '''
-    sel_arr = [
-        '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd',
-        'e', 'f'
-    ]
-    return func_rand_arr(sel_arr, 6)
+
+    return func_rand_arr(
+        list('0123456789abcdef'),
+        6
+    )
 
 
 def markdown2html(markdown_text):
@@ -249,64 +226,22 @@ def markdown2html(markdown_text):
     :param markdown_text:   The markdown text.
     :return:  The HTML text.
     '''
-    html = markdown.markdown(markdown_text,
-                             extensions=[
-                                 WikiLinkExtension(base_url='/wiki/',
-                                                   end_url=''),
-                                 'markdown.extensions.extra',
-                                 'markdown.extensions.toc',
-                                 'markdown.extensions.codehilite',
-                                 'markdown.extensions.meta'
-                             ])
+    html = markdown.markdown(
+        markdown_text,
+        extensions=[
+            WikiLinkExtension(base_url='/wiki/', end_url=''),
+            'markdown.extensions.extra',
+            'markdown.extensions.toc',
+            'markdown.extensions.codehilite',
+            'markdown.extensions.meta'
+        ]
+    )
     han_biaodians = ['。', '，', '；', '、', '！', '？']
     for han_biaodian in han_biaodians:
         html = html.replace(han_biaodian + '\n', han_biaodian)
     return tornado.escape.xhtml_escape(html)
 
 
-@deprecated(details='using `tag_pager` as the replacement.')
-def gen_pager_purecss(cat_slug, page_num, current):
-    '''
-    Generate pager of purecss.
-    '''
-    if page_num == 1:
-        return ''
-
-    pager_shouye = '''<li class="pure-menu-item {0}">
-    <a class="pure-menu-link" href="{1}">&lt;&lt; 首页</a></li>'''.format(
-        'hidden' if current <= 1 else '', cat_slug)
-
-    pager_pre = '''<li class="pure-menu-item {0}">
-                <a class="pure-menu-link" href="{1}/{2}">&lt; 前页</a>
-                </li>'''.format('hidden' if current <= 1 else '', cat_slug,
-                                current - 1)
-    pager_mid = ''
-    for ind in range(0, page_num):
-        tmp_mid = '''<li class="pure-menu-item {0}">
-                <a class="pure-menu-link" href="{1}/{2}">{2}</a></li>
-                '''.format('selected' if ind + 1 == current else '', cat_slug,
-                           ind + 1)
-        pager_mid += tmp_mid
-    pager_next = '''<li class="pure-menu-item {0}">
-                <a class="pure-menu-link" href="{1}/{2}">后页 &gt;</a>
-                </li> '''.format('hidden' if current >= page_num else '',
-                                 cat_slug, current + 1)
-    pager_last = '''<li class="pure-menu-item {0}">
-                <a hclass="pure-menu-link" ref="{1}/{2}">末页
-                &gt;&gt;</a>
-                </li> '''.format('hidden' if current >= page_num else '',
-                                 cat_slug, page_num)
-    pager = pager_shouye + pager_pre + pager_mid + pager_next + pager_last
-    return pager
-
-
-# def average_array(num_arr):
-#     '''
-#     The average value of the given array.
-#     '''
-#     return sum(num_arr) / len(num_arr)
-
-
 class ConfigDefault(object):
     '''
     Class for the default configuration.
@@ -334,6 +269,7 @@ class ConfigDefault(object):
         'pass': '',
     }
 
+    # 权限的缺省值
     ROLE_CFG = {
         'view': '',
         'add': '1000',
@@ -343,35 +279,6 @@ class ConfigDefault(object):
     }
 
 
-# def get_analyzer():
-#     '''
-#     Get the analyzer for whoosh of difference language. Currrent only for zh and en.
-#     '''
-#     alyzer = {
-#         'zh': ChineseAnalyzer,
-#         'en': StemmingAnalyzer,
-#     }
-#
-#     # cfg_var = dir(cfg)
-#     # site_cfg = cfg.SITE_CFG if 'SITE_CFG' in cfg_var else ConfigDefault.SITE_CFG
-#
-#     site_cfg = config.SITE_CFG
-#
-#     site_cfg['LANG'] = site_cfg.get('LANG', 'zh')
-#
-#     if site_cfg['LANG'] == 'zh' and ChineseAnalyzer:
-#         pass
-#     else:
-#         site_cfg['LANG'] = 'en'
-#
-#    print('x' * 20)
-#    print(site_cfg)
-#
-#    # print(site_cfg['LANG'])
-#    # return alyzer[site_cfg['LANG']]
-#    return StemmingAnalyzer
-
-
 def get_cfg():
     '''
     Get the configure value.
@@ -425,11 +332,10 @@ def get_cfg():
                                    password=db_cfg['pass'],
                                    host=db_cfg.get('host', '127.0.0.1'),
                                    port=db_cfg.get('port', '5432'),
-                                   autocommit=True,
+                                   # autocommit=True,
                                    autorollback=True)
 
     if 'REDIS_CFG' in cfg_var:
-
         redis_cfg = cfg.REDIS_CFG
         if not redis_cfg.get('host'):
             redis_cfg['host'] = 'localhost'
@@ -438,15 +344,14 @@ def get_cfg():
         if not redis_cfg.get('pass'):
             redis_cfg['pass'] = None
     else:
-
         redis_cfg = {'host': 'localhost', 'port': 6379, 'pass': None}
 
     return (db_con, smtp_cfg, site_cfg, role_cfg, redis_cfg)
 
 
 def ts_helper():
-    timestamp = int(time.time())
-    ts1d = timestamp - 24 * 60 * 60
-    ts7d = timestamp - 7 * 24 * 60 * 60
-    ts30d = timestamp - 30 * 24 * 60 * 60
+    the_timestamp = int(time.time())
+    ts1d = the_timestamp - 24 * 60 * 60
+    ts7d = the_timestamp - 7 * 24 * 60 * 60
+    ts30d = the_timestamp - 30 * 24 * 60 * 60
     return [x * 1000 for x in (ts1d, ts7d, ts30d)]
