@@ -19,6 +19,7 @@ class CategoryAjaxHandler(BaseHandler):
     '''
     Handler for category.
     '''
+
     def initialize(self, **kwargs):
         super().initialize()
         self.tmpl_router = 'category_ajax'
@@ -85,7 +86,7 @@ class CategoryAjaxHandler(BaseHandler):
             pass
         else:
             return False
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         post_data['user_name'] = self.get_current_user()
 
@@ -111,7 +112,7 @@ class CategoryAjaxHandler(BaseHandler):
             pass
         else:
             return False
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         post_data['user_name'] = self.get_current_user()
 
