@@ -3,7 +3,7 @@
 Hander for entiey, such as files or URL.
 '''
 import tornado.web
-
+import json
 import config
 from torcms.core.base_handler import BaseHandler
 from torcms.model.entity2user_model import MEntity2User
@@ -13,6 +13,7 @@ class Entity2UserHandler(BaseHandler):
     '''
     Hander for entity, such as files or URL.
     '''
+
     def initialize(self, **kwargs):
         super().initialize()
 
@@ -28,13 +29,40 @@ class Entity2UserHandler(BaseHandler):
         else:
             self.render('misc/html/404.html', kwd={}, userinfo=self.userinfo)
 
+    def post(self, *args, **kwargs):
+        url_str = args[0]
+        url_arr = self.parse_url(url_str)
+        if url_str == 'count':
+            self.down_count_by_year()
+
+    def down_count_by_year(self):
+        '''
+        List the entities of the user.
+        '''
+        post_data = self.get_request_arguments()
+        down_year = post_data.get('down_year', '2022')
+        count = MEntity2User.total_number_by_year(down_year)
+        output = {'count': count}
+        return json.dump(output, self)
+
     @tornado.web.authenticated
     def all_list(self, cur_p=''):
         '''
         List the entities of the user.
         '''
-        # ToDo: 代码与 entity_handler 中 list 方法有重复
-        current_page_number = int(cur_p) if cur_p else 1
+        current_page_number = 1
+        if cur_p == '':
+            current_page_number = 1
+        else:
+            try:
+                current_page_number = int(cur_p)
+            except TypeError:
+                current_page_number = 1
+            except Exception as err:
+                print(err.args)
+                print(str(err))
+                print(repr(err))
+
         current_page_number = 1 if current_page_number < 1 else current_page_number
 
         kwd = {'current_page': current_page_number}
@@ -52,7 +80,19 @@ class Entity2UserHandler(BaseHandler):
         '''
         List the entities of the user.
         '''
-        current_page_number = int(cur_p) if cur_p else 1
+        current_page_number = 1
+        if cur_p == '':
+            current_page_number = 1
+        else:
+            try:
+                current_page_number = int(cur_p)
+            except TypeError:
+                current_page_number = 1
+            except Exception as err:
+                print(err.args)
+                print(str(err))
+                print(repr(err))
+
         current_page_number = 1 if current_page_number < 1 else current_page_number
 
         kwd = {'current_page': current_page_number}
