@@ -83,7 +83,19 @@ class EntityHandler(BaseHandler):
         Lists of the entities.
         '''
 
-        current_page_number = int(cur_p) if cur_p else 1
+        current_page_number = 1
+        if cur_p == '':
+            current_page_number = 1
+        else:
+            try:
+                current_page_number = int(cur_p)
+            except TypeError:
+                current_page_number = 1
+            except Exception as err:
+                print(err.args)
+                print(str(err))
+                print(repr(err))
+
         current_page_number = 1 if current_page_number < 1 else current_page_number
 
         kwd = {'current_page': current_page_number}
@@ -102,8 +114,16 @@ class EntityHandler(BaseHandler):
         for key in self.request.arguments:
             post_data[key] = self.get_arguments(key)[0]
 
-        down_url = MPost.get_by_uid(down_uid).extinfo.get(
+        down_url1 = MPost.get_by_uid(down_uid).extinfo.get(
             'tag__file_download', '')
+        down_url2 = MPost.get_by_uid(down_uid).extinfo.get(
+            'tag_file_download', '')
+
+        if down_url1:
+            down_url = down_url1
+        else:
+            down_url = down_url2
+
         if down_url:
 
             if allowed_file(down_url):
@@ -143,7 +163,7 @@ class EntityHandler(BaseHandler):
         '''
         kwd = {
             'pager': '',
-            'err_info':''
+            'err_info': ''
         }
         self.render('misc/entity/entity_add.html',
                     cfg=config.CMS_CFG,
@@ -155,7 +175,7 @@ class EntityHandler(BaseHandler):
         '''
         Add the entity. All the information got from the post data.
         '''
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         if 'kind' in post_data:
             if post_data['kind'] == '1':
