@@ -7,6 +7,7 @@ import json
 import math
 
 import tornado.escape
+from urllib.parse import unquote
 from html2text import html2text
 
 from config import CMS_CFG, router_post
@@ -78,25 +79,30 @@ class FilterHandler(BaseHandler):
     '''
     List view,by category uid. The list could be filtered.
     '''
+
     def initialize(self, **kwargs):
         super().initialize()
 
     def get(self, *args, **kwargs):
-        url_str = args[0]
+        _kwargs = kwargs
+
+        # 会有莫名其妙的空格。需要去掉。
+        url_str = unquote(args[0]).strip()
 
         logger.info('infocat get url_str: {0}'.format(url_str))
 
-        if len(url_str) == 4:
-            self.list(url_str)
-        elif len(url_str) > 4:
+        url_arr = self.parse_url(url_str)
 
+        if len(url_arr) == 1:
+            self.list(url_str)
+        elif len(url_arr) >= 2:
             self.echo_html(url_str)
         else:
             kwd = {
                 'title': '',
                 'info': '404. Page not found!',
             }
-            self.render('misc/html/404.html', kwd=kwd)
+            self.render('misc/html/404.html', kwd=kwd, userinfo=self.userinfo)
 
     def post(self, *args, **kwargs):
         url_str = args[0]
@@ -108,8 +114,9 @@ class FilterHandler(BaseHandler):
     def gen_redis_kw(self):
         condition = {}
         if self.get_current_user() and self.userinfo:
-            redis_kw = redisvr.smembers(CMS_CFG['redis_kw'] +
-                                        self.userinfo.user_name)
+            redis_kw = redisvr.smembers(
+                CMS_CFG['redis_kw'] + self.userinfo.user_name
+            )
         else:
             redis_kw = []
 
@@ -132,7 +139,7 @@ class FilterHandler(BaseHandler):
         url_arr = self.parse_url(url_str)
         sig = url_arr[0]
 
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
         sort_option = post_data.get('sort', '')
 
         num = (len(url_arr) - 2) // 2
@@ -145,6 +152,7 @@ class FilterHandler(BaseHandler):
             condition['def_cat_uid'] = sig
 
         fenye_num = 1
+        logger.info(f'num: {num}')
         for idx in range(num):
             ckey = url_arr[idx * 2 + 2]
             tval = url_arr[idx * 2 + 3]
@@ -157,8 +165,11 @@ class FilterHandler(BaseHandler):
                 continue
             else:
                 cval = tval
-            ckey = 'tag_' + ckey
-            condition[ckey] = cval
+
+            condition['_tag_' + ckey] = cval
+            # condition['tag_' + ckey] = cval
+
+            logger.info(f'TorCMS:: post handler: {condition}')
 
         if url_arr[1] == 'con':
             infos = MPost.query_list_pager(condition,
@@ -170,9 +181,9 @@ class FilterHandler(BaseHandler):
             allinfos = MPost.query_under_condition(condition,
                                                    kind=catinfo.kind,
                                                    sort_option=sort_option)
-            self.write(
-                tornado.escape.xhtml_unescape(
-                    echo_html_fenye_str(allinfos.count(), fenye_num)))
+            self.write(tornado.escape.xhtml_unescape(
+                echo_html_fenye_str(allinfos.count(), fenye_num)
+            ))
 
     def get_info_num(self, url_str):
         '''
@@ -248,6 +259,17 @@ class FilterHandler(BaseHandler):
         bread_crumb_nav_str = '<li>当前位置：<a href="/">信息</a></li>'
 
         _catinfo = MCategory.get_by_uid(catid)
+
+        if _catinfo:
+            pass
+        else:
+            kwd = {
+                'title': '',
+
+                'info': '404. Can not find the category!',
+            }
+            self.render('misc/html/404.html', kwd=kwd, userinfo=self.userinfo)
+
         logger.info('Infocat input: {0}'.format(_catinfo))
         if _catinfo.pid == '0000':
             pcatinfo = _catinfo
@@ -290,8 +312,9 @@ class FilterHandler(BaseHandler):
 
         # cat_rec = MCategory.get_by_uid(catid)
         if self.get_current_user() and self.userinfo:
-            redis_kw = redisvr.smembers(CMS_CFG['redis_kw'] +
-                                        self.userinfo.user_name)
+            redis_kw = redisvr.smembers(
+                CMS_CFG['redis_kw'] + self.userinfo.user_name
+            )
         else:
             redis_kw = []
         kw_condition_arr = []
