@@ -18,6 +18,7 @@ class LinkHandler(BaseHandler):
     '''
     Handler for links.
     '''
+
     def initialize(self, **kwargs):
         super().initialize()
 
@@ -108,7 +109,7 @@ class LinkHandler(BaseHandler):
             pass
         else:
             return False
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         post_data['user_name'] = self.get_current_user()
 
@@ -151,7 +152,7 @@ class LinkHandler(BaseHandler):
 
         if not rec:
             kwd = {'info': '您要找的分类不存在。'}
-            self.render('misc/html/404.html', kwd=kwd)
+            self.render('misc/html/404.html', kwd=kwd, userinfo=self.userinfo)
             return False
 
         kwd = {
@@ -176,7 +177,7 @@ class LinkHandler(BaseHandler):
             pass
         else:
             return False
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         post_data['user_name'] = self.get_current_user()
 
@@ -203,7 +204,7 @@ class LinkHandler(BaseHandler):
             pass
         else:
             return False
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         post_data['user_name'] = self.get_current_user()
 
@@ -240,6 +241,7 @@ class LinkPartialHandler(LinkHandler):
     '''
     Partially render for user handler.
     '''
+
     def initialize(self, **kwargs):
         super().initialize()
         self.is_p = True
