@@ -25,6 +25,7 @@ class ListHandler(BaseHandler):
     分类访问
     如果order = True,列表可以进行排序操作。
     '''
+
     def initialize(self, **kwargs):
         super().initialize()
         self.kind = kwargs.get('kind', '1')
@@ -37,6 +38,7 @@ class ListHandler(BaseHandler):
         if len(url_arr) == 1:
             self.list_catalog(url_str)
         elif len(url_arr) == 2:
+
             if url_arr[0] == 'j_subcat':
                 self.ajax_subcat_arr(url_arr[1])
             elif url_arr[0] == 'j_kindcat':
@@ -45,12 +47,13 @@ class ListHandler(BaseHandler):
                 self.ajax_list_catalog(url_arr[1])
             else:
                 self.list_catalog(url_arr[0], cur_p=url_arr[1])
+
         else:
             kwd = {
                 'title': '',
                 'info': '404. Page not found!',
             }
-            self.render('misc/html/404.html', kwd=kwd)
+            self.render('misc/html/404.html', kwd=kwd, userinfo=self.userinfo)
 
     def ajax_list_catalog(self, catid):
         '''
@@ -87,23 +90,35 @@ class ListHandler(BaseHandler):
             out_arr[catinfo.uid] = catinfo.name
         json.dump(out_arr, self)
 
-    def list_catalog(self, cat_slug, **kwargs):
+    def list_catalog(self, cat_slug, cur_p='', **kwargs):
         '''
         listing the posts via category
 
         根据分类（cat_slug）显示分类列表
         '''
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
         tag = post_data.get('tag', '')
 
         def get_pager_idx():
             '''
             Get the pager index.
             '''
-            cur_p = kwargs.get('cur_p')
-            the_num = int(cur_p) if cur_p else 1
-            the_num = 1 if the_num < 1 else the_num
-            return the_num
+
+            current_page_number = 1
+            if cur_p == '':
+                current_page_number = 1
+            else:
+                try:
+                    current_page_number = int(cur_p)
+                except TypeError:
+                    current_page_number = 1
+                except Exception as err:
+                    print(err.args)
+                    print(str(err))
+                    print(repr(err))
+
+            current_page_number = 1 if current_page_number < 1 else current_page_number
+            return current_page_number
 
         current_page_num = get_pager_idx()
         cat_rec = MCategory.get_by_slug(cat_slug)
@@ -135,14 +150,12 @@ class ListHandler(BaseHandler):
         infos = MPost2Catalog.query_pager_by_slug(cat_slug,
                                                   current_page_num,
                                                   tag=tag,
-                                                  order=self.order)
+                                                  order=self.order
+                                                  )
 
-        # ToDo: `gen_pager_purecss` should not use any more.
         self.render(tmpl,
                     catinfo=cat_rec,
                     infos=infos,
-                    pager=tools.gen_pager_purecss('/list/{0}'.format(cat_slug),
-                                                  page_num, current_page_num),
                     userinfo=self.userinfo,
                     html2text=html2text,
                     cfg=CMS_CFG,
@@ -155,5 +168,6 @@ class TagListHandler(BaseHandler):
     List the infos by the slug of the catalog.
     via: `/tag/cat_slug`
     '''
+
     def get(self, *args, **kwargs):
         self.redirect('/list/{0}'.format(args[0]))
