@@ -26,20 +26,16 @@ class LogHandler(BaseHandler):
 
         url_arr = self.parse_url(url_str)
 
-        if url_str == '':
-            self.list()
-        elif len(url_arr) == 1:
-            if url_arr[0] == 'pageview':
+        if len(url_arr) == 1:
+            if url_arr[0] in ['pageview', 'search']:
                 # 访问量
-                self.pageview()
-            else:
-                # 留存时间
-                self.list(url_arr[0])
-        elif len(url_arr) == 2:
-            if url_arr[0] == 'pageview':
-                self.pageview(url_arr[1])
-            else:
-                self.user_log_list(url_arr[0], url_arr[1])
+                self.search()
+
+        # elif len(url_arr) == 2:
+        #     if url_arr[0] == 'pageview':
+        #         self.pageview(url_arr[1])
+            # else:
+            #     self.user_log_list(url_arr[0], url_arr[1])
         else:
             self.render('misc/html/404.html', userinfo=self.userinfo, kwd={})
 
@@ -54,6 +50,8 @@ class LogHandler(BaseHandler):
                 self.add(uid=url_arr[1])
             else:
                 self.add()
+        elif url_arr[0] == 'search':
+            self.search()
 
         else:
             self.show404()
@@ -78,10 +76,18 @@ class LogHandler(BaseHandler):
         View the list of the Log.
         '''
 
+        current_page_number = 1
         if cur_p == '':
             current_page_number = 1
         else:
-            current_page_number = int(cur_p)
+            try:
+                current_page_number = int(cur_p)
+            except TypeError:
+                current_page_number = 1
+            except Exception as err:
+                print(err.args)
+                print(str(err))
+                print(repr(err))
 
         current_page_number = 1 if current_page_number < 1 else current_page_number
 
@@ -114,10 +120,18 @@ class LogHandler(BaseHandler):
         View the list of the Log.
         '''
 
+        current_page_number = 1
         if cur_p == '':
             current_page_number = 1
         else:
-            current_page_number = int(cur_p)
+            try:
+                current_page_number = int(cur_p)
+            except TypeError:
+                current_page_number = 1
+            except Exception as err:
+                print(err.args)
+                print(str(err))
+                print(repr(err))
 
         current_page_number = 1 if current_page_number < 1 else current_page_number
 
@@ -149,10 +163,18 @@ class LogHandler(BaseHandler):
         View the list of the Log.
         '''
 
+        current_page_number = 1
         if cur_p == '':
             current_page_number = 1
         else:
-            current_page_number = int(cur_p)
+            try:
+                current_page_number = int(cur_p)
+            except TypeError:
+                current_page_number = 1
+            except Exception as err:
+                print(err.args)
+                print(str(err))
+                print(repr(err))
 
         current_page_number = 1 if current_page_number < 1 else current_page_number
 
@@ -172,18 +194,28 @@ class LogHandler(BaseHandler):
 
         self.render('misc/log/pageview.html',
                     kwd=kwd,
-                    infos=MLog.query_all_pageview(
-                        current_page_num=current_page_number),
+                    # infos=MLog.query_all_pageview(
+                    #     current_page_num=current_page_number),
                     postinfo=postinfo,
                     arr_num=arr_num,
                     format_date=tools.format_date,
                     userinfo=self.userinfo)
 
+    def search(self, **kwargs):
+        post_data = self.get_request_arguments()
+        url = post_data.get('url')
+        res = MLog.get_by_url(url)
+        self.render('misc/log/pageview_search.html',
+                    res=res,
+                    format_date=tools.format_date,
+                    userinfo=self.userinfo)
+
 
 class LogPartialHandler(LogHandler):
     '''
     Partially render for user handler.
     '''
+
     def initialize(self, **kwargs):
         super().initialize()
         self.is_p = True
