@@ -1,4 +1,9 @@
-import config
+'''
+Handler for `valid==0`.
+
+ToDo: fix it.
+'''
+
 from config import CMS_CFG, router_post
 from torcms.core.base_handler import BaseHandler
 from torcms.model.nullify_info_model import MNullifyInfo
@@ -17,18 +22,31 @@ class NullifyInfoHandler(BaseHandler):
 
             self.list(url_arr[0], cur_p=url_arr[1])
 
-    def list(self, list, **kwargs):
+    def list(self, _, **kwargs):
         '''
         List the replies.
         '''
+
         def get_pager_idx():
             '''
             Get the pager index.
             '''
             cur_p = kwargs.get('cur_p')
-            the_num = int(cur_p) if cur_p else 1
-            the_num = 1 if the_num < 1 else the_num
-            return the_num
+            current_page_number = 1
+            if cur_p == '':
+                current_page_number = 1
+            else:
+                try:
+                    current_page_number = int(cur_p)
+                except TypeError:
+                    current_page_number = 1
+                except Exception as err:
+                    print(err.args)
+                    print(str(err))
+                    print(repr(err))
+
+            current_page_number = 1 if current_page_number < 1 else current_page_number
+            return current_page_number
 
         current_page_num = get_pager_idx()
         num_of_cat = MNullifyInfo.count_of_certain()
