@@ -5,6 +5,7 @@ The basic HTML Page handler.
 
 import json
 import random
+
 from concurrent.futures import ThreadPoolExecutor
 
 import tornado.escape
@@ -37,7 +38,14 @@ def update_category(uid, post_data):
 
     # deprecated
     # catid = kwargs['catid'] if MCategory.get_by_uid(kwargs.get('catid')) else None
-    # post_data = self.get_post_data()
+    # post_data = self.get_request_arguments()
+
+    '''
+    在前端，使用 `gcat0`，`gcat1`，`gcat2` 等，作为分类的参数。
+    因为一个 post 可能会有多个分类，再定义第1分类的 key ：
+        'def_cat_uid'： 第1分类
+        'def_cat_pid' : 分1分类的父类
+    '''
     if 'gcat0' in post_data:
         pass
     else:
@@ -76,10 +84,10 @@ def update_category(uid, post_data):
         the_cats_dict['def_cat_uid'] = def_cat_id
         the_cats_dict['def_cat_pid'] = MCategory.get_by_uid(def_cat_id).pid
 
-    # Add the category
     logger.info('Update category: {0}'.format(the_cats_arr))
     logger.info('Update category: {0}'.format(the_cats_dict))
 
+    # Add the category
     MPost.update_jsonb(uid, the_cats_dict)
 
     for index, idx_catid in enumerate(the_cats_arr):
@@ -92,36 +100,37 @@ def update_category(uid, post_data):
             MPost2Catalog.remove_relation(uid, cur_info.tag_id)
 
 
-def update_label(signature, post_data):
+def update_label(post_id, post_data):
     '''
     Update the label when updating.
     '''
-    current_tag_infos = MPost2Label.get_by_uid(signature).objects()
+    current_tag_infos = MPost2Label.get_by_uid(post_id).objects()
     if 'tags' in post_data:
         pass
     else:
         return False
+    if '；' in post_data['tags']:
+        tags_arr = [x.strip() for x in post_data['tags'].split('；')]
+    elif ',' in post_data['tags']:
+        tags_arr = [x.strip() for x in post_data['tags'].split(',')]
+    elif '，' in post_data['tags']:
+        tags_arr = [x.strip() for x in post_data['tags'].split('，')]
+    elif ';' in post_data['tags']:
+        tags_arr = [x.strip() for x in post_data['tags'].split(';')]
+    else:
+        tags_arr = [x.strip() for x in post_data['tags'].split(' ')]
 
-    tags_arr = [x.strip() for x in post_data['tags'].split(',')]
     for tag_name in tags_arr:
         if tag_name == '':
             pass
         else:
-            MPost2Label.add_record(signature, tag_name, 1)
+            MPost2Label.add_record(post_id, tag_name, 1)
 
     for cur_info in current_tag_infos:
         if cur_info.tag_name in tags_arr:
             pass
         else:
-            MPost2Label.remove_relation(signature, cur_info.tag_id)
-
-
-# def ts_helper():
-#     timestamp = int(time.time())
-#     ts1d = timestamp - 24 * 60 * 60
-#     ts7d = timestamp - 7 * 24 * 60 * 60
-#     ts30d = timestamp - 30 * 24 * 60 * 60
-#     return (ts1d, ts7d, ts30d)
+            MPost2Label.remove_relation(post_id, cur_info.tag_id)
 
 
 class PostHandler(BaseHandler):
@@ -151,7 +160,7 @@ class PostHandler(BaseHandler):
                 self._to_add(uid=url_arr[1])
             else:
                 self._to_add()
-        elif len(url_arr) == 1 and len(url_str) in [4, 5]:
+        elif len(url_arr) == 1 and len(url_str) >= 4:
             self._view_or_add(url_str)
         elif len(url_arr) == 2:
             dict_get = {
@@ -180,13 +189,10 @@ class PostHandler(BaseHandler):
             self._change_kind(url_arr[1])
         elif url_arr[0] in ['_cat_add']:
             self.add(catid=url_arr[1])
-        elif len(url_arr) == 1:
-            # Todo: should not exists.
-            if len(url_str) in [4, 5]:
-                self.add(uid=url_str)
+        elif len(url_arr) == 1 and len(url_str) >= 4:
+            self.add(uid=url_str)
         elif url_arr[0] == 'rel' and len(url_arr) == 3:
             self._add_relation(url_arr[1], url_arr[2])
-
         else:
             self.show404()
 
@@ -218,12 +224,7 @@ class PostHandler(BaseHandler):
         :return: the temaplte path.
         '''
 
-        if 'def_cat_uid' in rec.extinfo and rec.extinfo['def_cat_uid'] != '':
-            cat_id = rec.extinfo['def_cat_uid']
-        elif 'gcat0' in rec.extinfo and rec.extinfo['gcat0'] != '':
-            cat_id = rec.extinfo['gcat0']
-        else:
-            cat_id = None
+        cat_id = self.__get_cat_id(rec)
 
         logger.info('For templates: catid: {0},  filter_view: {1}'.format(
             cat_id, self.filter_view))
@@ -234,6 +235,16 @@ class PostHandler(BaseHandler):
             tmpl = 'post_{0}/post_view.html'.format(self.kind)
         return tmpl
 
+    def __get_cat_id(self, postinfo):
+
+        catinfo = MPost2Catalog.get_first_category(postinfo.uid)
+        if catinfo:
+            cat_id = catinfo.tag_id
+        else:
+            cat_id = None
+
+        return cat_id
+
     @tornado.web.authenticated
     @privilege.auth_add
     def _to_add_with_category(self, catid):
@@ -261,7 +272,16 @@ class PostHandler(BaseHandler):
         '''
         postinfo = MPost.get_by_uid(uid)
         if postinfo:
-            self.viewinfo(postinfo)
+            if postinfo.kind == self.kind:
+                self.viewinfo(postinfo)
+            else:
+                self.redirect(
+                    '/{0}/{1}'.format(
+                        router_post[postinfo.kind],
+                        postinfo.uid
+                    ),
+                    permanent=True)
+
         elif self.userinfo:
             self._to_add(uid=uid)
         else:
@@ -307,14 +327,9 @@ class PostHandler(BaseHandler):
         else:
             return self.show404()
 
-        if 'def_cat_uid' in postinfo.extinfo:
-            catid = postinfo.extinfo['def_cat_uid']
-        elif 'gcat0' in postinfo.extinfo:
-            catid = postinfo.extinfo['gcat0']
-        else:
-            catid = ''
+        catid = self.__get_cat_id(postinfo)
 
-        if len(catid) == 4:
+        if catid and len(catid) == 4:
             pass
         else:
             catid = ''
@@ -374,33 +389,14 @@ class PostHandler(BaseHandler):
         if last_post_id and MPost.get_by_uid(last_post_id):
             self._add_relation(last_post_id, post_id)
 
-    def redirect_kind(self, postinfo):
-        '''
-        Redirect according the kind of the post.
-        :param postinfo: the postinfo
-        :return: None
-        '''
-        logger.warning('info kind:{0} '.format(postinfo.kind))
-
-        # If not, there must be something wrong.
-        if postinfo.kind == self.kind:
-            pass
-        else:
-            self.redirect('/{0}/{1}'.format(router_post[postinfo.kind],
-                                            postinfo.uid),
-                          permanent=True)
-
     @privilege.auth_view
     def viewinfo(self, postinfo):
         '''
         查看 Post.
         '''
-        self.redirect_kind(postinfo)
 
         __ext_catid = postinfo.extinfo.get('def_cat_uid', '')
-
         cat_enum1 = MCategory.get_qian2(__ext_catid[:2]) if __ext_catid else []
-
         rand_recs, rel_recs = self.fetch_additional_posts(postinfo.uid)
 
         self._chuli_cookie_relation(postinfo.uid)
@@ -439,13 +435,11 @@ class PostHandler(BaseHandler):
             kwd=dict(kwd, **self.ext_view_kwd(postinfo)),
             postinfo=postinfo,
             userinfo=self.userinfo,
-            author=postinfo.user_name,  # Todo: remove the key `author`.
             catinfo=catinfo,
             pcatinfo=p_catinfo,
             relations=rel_recs,
             rand_recs=rand_recs,
-            subcats=MCategory.query_sub_cat(p_catinfo.uid)
-            if p_catinfo else '',
+            subcats=MCategory.query_sub_cat(p_catinfo.uid) if p_catinfo else '',
             ad_switch=random.randint(1, 18),
             tag_info=filter(lambda x: not x.tag_name.startswith('_'),
                             MPost2Label.get_by_uid(postinfo.uid).objects()),
@@ -527,14 +521,14 @@ class PostHandler(BaseHandler):
         MRelation.add_relation(t_uid, f_uid, 1)
         return True
 
-    def fetch_post_data(self):
+    def __parse_post_data(self):
         '''
         fetch post accessed data. post_data, and ext_dic.
         '''
         post_data = {}
         ext_dic = {}
         for key in self.request.arguments:
-            if key.startswith('ext_') or key.startswith('tag_'):
+            if key.startswith('ext_') or key.startswith('tag_') or key.startswith('_tag_'):
                 ext_dic[key] = self.get_argument(key, default='')
             else:
                 post_data[key] = self.get_arguments(key)[0]
@@ -548,7 +542,7 @@ class PostHandler(BaseHandler):
             ext_dic['def_tag_arr'] = [
                 x.strip()
                 for x in post_data['tags'].strip().strip(',').split(',')
-                ]
+            ]
         ext_dic = dict(ext_dic, **self.ext_post_data(postdata=post_data))
 
         return (post_data, ext_dic)
@@ -566,7 +560,7 @@ class PostHandler(BaseHandler):
         else:
             uid = self._gen_uid()
 
-        post_data, ext_dic = self.fetch_post_data()
+        post_data, ext_dic = self.__parse_post_data()
 
         title = post_data['title'].strip()
 
@@ -577,28 +571,28 @@ class PostHandler(BaseHandler):
             }
             self.render('misc/html/404.html', userinfo=self.userinfo, kwd=kwd)
 
-        if 'gcat0' in post_data:
-            pass
-        else:
-            return False
-
         if 'valid' in post_data:
             post_data['valid'] = int(post_data['valid'])
         else:
             post_data['valid'] = 1
 
-        ext_dic['def_uid'] = uid
+        # 在应用中，会有分类的逻辑，需要处理
+        if 'gcat0' in post_data:
+            pass
+        else:
+            return False
+        ext_dic['def_uid'] = uid  # 此 key 用于更新文档时在历史记录中跟踪原 uid .
         ext_dic['gcat0'] = post_data['gcat0']
         ext_dic['def_cat_uid'] = post_data['gcat0']
-        MPost.modify_meta(ext_dic['def_uid'], post_data, extinfo=ext_dic)
-        kwargs.pop('uid', None)  # delete `uid` if exists in kwargs
+
+        # MPost中并没有分类的逻辑关系
+        MPost.add_or_update_post(uid, post_data, extinfo=ext_dic)
+        # kwargs.pop('uid', None)  # delete `uid` if exists in kwargs
 
         self._add_download_entity(ext_dic)
 
-        # self.update_tag(uid=ext_dic['def_uid'], **kwargs)
-
-        update_category(ext_dic['def_uid'], post_data)
-        update_label(ext_dic['def_uid'], post_data)
+        update_category(uid, post_data)
+        update_label(uid, post_data)
         # self.update_label(uid)
 
         # cele_gen_whoosh.delay()
@@ -620,7 +614,7 @@ class PostHandler(BaseHandler):
         else:
             return False
 
-        post_data, ext_dic = self.fetch_post_data()
+        post_data, ext_dic = self.__parse_post_data()
         if 'gcat0' in post_data:
             pass
         else:
@@ -631,7 +625,21 @@ class PostHandler(BaseHandler):
         else:
             post_data['valid'] = postinfo.valid
 
-        ext_dic['def_uid'] = str(uid)
+        ext_dic['def_uid'] = uid
+        # 用于判断是第几轮审核
+        if postinfo.state[1] == '3':
+            edit_count = int(postinfo.extinfo.get('def_edit_count', 0)) + 1
+        else:
+            edit_count = int(postinfo.extinfo.get('def_edit_count', 0))
+
+        ext_dic['def_edit_count'] = edit_count
+        # 用于记录审核通过后第几轮修改
+        if postinfo.state[1] == '2':
+            approved_count = int(postinfo.extinfo.get('def_approved_count', 0)) + 1
+        else:
+            approved_count = int(postinfo.extinfo.get('def_approved_count', 0))
+
+        ext_dic['def_approved_count'] = approved_count
 
         cnt_old = tornado.escape.xhtml_unescape(postinfo.cnt_md).strip()
         cnt_new = post_data['cnt_md'].strip()
@@ -640,7 +648,23 @@ class PostHandler(BaseHandler):
         else:
             MPostHist.create_post_history(postinfo, self.userinfo)
 
-        MPost.modify_meta(uid, post_data, extinfo=ext_dic)
+        MPost.add_or_update_post(uid, post_data, extinfo=ext_dic)
+
+        # todo:应该判断当前审核状态，是否可以进行修改状态。
+        if postinfo.state[1] == '3':
+            state_arr = ['a', 'b', 'c', 'd', 'e', 'f']
+            if len(state_arr) > edit_count:
+                pstate = str(state_arr[edit_count]) + '0' + postinfo.state[2:]
+
+                MPost.update_state(uid, pstate)
+
+        if postinfo.state[1] == '2':
+            approved_state_arr = ['1', '2', '3', '4', '5', '6', '7', '8', '9']
+            if len(approved_state_arr) > approved_count:
+                pstate = postinfo.state[0] + '1' + str(approved_state_arr[approved_count]) + '0'
+            else:
+                pstate = postinfo.state[0] + '190'
+            MPost.update_state(uid, pstate)
 
         self._add_download_entity(ext_dic)
         # self.update_tag(uid=uid)
@@ -716,8 +740,9 @@ class PostHandler(BaseHandler):
         return {}
 
     def _add_download_entity(self, ext_dic):
-        download_url = ext_dic['tag_file_download'].strip().lower() if (
-            'tag_file_download' in ext_dic) else ''
+        download_url = (ext_dic['tag_file_download'].strip().lower()
+                        if ('tag_file_download' in ext_dic)
+                        else '')
         the_entity = MEntity.get_id_by_impath(download_url)
         if the_entity:
             return True
@@ -750,7 +775,7 @@ class PostHandler(BaseHandler):
         To modify the category of the post, and kind.
         '''
 
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         logger.info('admin post update: {0}'.format(post_data))
 
