@@ -17,6 +17,7 @@ class ReplyHandler(BaseHandler):
     '''
     Handler for reply.
     '''
+
     def initialize(self):
         super().initialize()
 
@@ -51,10 +52,18 @@ class ReplyHandler(BaseHandler):
         '''
         List the replies.
         '''
+        current_page_number = 1
         if cur_p == '':
             current_page_number = 1
         else:
-            current_page_number = int(cur_p)
+            try:
+                current_page_number = int(cur_p)
+            except TypeError:
+                current_page_number = 1
+            except Exception as err:
+                print(err.args)
+                print(str(err))
+                print(repr(err))
 
         current_page_number = 1 if current_page_number < 1 else current_page_number
 
@@ -109,7 +118,7 @@ class ReplyHandler(BaseHandler):
         '''
         Adding reply to a post.
         '''
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         post_data['user_name'] = self.userinfo.user_name
         post_data['user_id'] = self.userinfo.uid
@@ -166,7 +175,7 @@ class ReplyHandler(BaseHandler):
         '''
         Adding reply
         '''
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         post_data['user_name'] = self.userinfo.user_name
         post_data['user_id'] = self.userinfo.uid
@@ -185,7 +194,7 @@ class ReplyHandler(BaseHandler):
         '''
         Adding comment to a post.
         '''
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
         post_data['user_name'] = self.userinfo.user_name
         post_data['user_id'] = self.userinfo.uid
         post_data['category'] = cat
