@@ -16,6 +16,7 @@ from torcms.core.base_handler import BaseHandler
 from torcms.model.wiki_hist_model import MWikiHist
 from torcms.model.wiki_model import MWiki
 
+
 # from celery_server import cele_gen_whoosh
 
 
@@ -112,7 +113,7 @@ class WikiHandler(BaseHandler):
             pass
         else:
             return False
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
         post_data['user_name'] = self.userinfo.user_name
 
         cnt_old = tornado.escape.xhtml_unescape(postinfo.cnt_md).strip()
@@ -185,7 +186,7 @@ class WikiHandler(BaseHandler):
         Add wiki
         '''
 
-        post_data = self.get_post_data()
+        post_data = self.get_request_arguments()
 
         if title == '':
             pass
