@@ -3,12 +3,11 @@
 Model for Posts.
 '''
 
-from torcms.model.abc_model import Mabc
 from torcms.model.category_model import MCategory
 from torcms.model.core_tab import TabPost, TabPost2Tag, TabTag
 
 
-class MCatalog(Mabc):
+class MCatalog():
     '''
     Model for catalog list.
     '''
