@@ -3,14 +3,15 @@
 数据库操作，处理分类
 '''
 
-from torcms.model.abc_model import Mabc, MHelper
+from torcms.model.abc_model import MHelper
 from torcms.model.core_tab import TabPost, TabPost2Tag, TabTag
 
 
-class MCategory(Mabc):
+class MCategory():
     '''
     Model for category
     '''
+
     @staticmethod
     def delete(uid):
         '''
@@ -51,15 +52,15 @@ class MCategory(Mabc):
 
     @staticmethod
     def get_parent_list(kind='1'):
-        return TabTag.select().where((TabTag.kind == kind)
-                                     & (TabTag.uid.endswith('00'))).order_by(
-                                         TabTag.uid)
+        return TabTag.select().where(
+            (TabTag.kind == kind) & (TabTag.uid.endswith('00'))
+        ).order_by(TabTag.uid)
 
     @staticmethod
     def query_kind_cat(kind_sig):
-        return TabTag.select().where((TabTag.kind == kind_sig)
-                                     & (TabTag.pid == '0000')).order_by(
-                                         TabTag.order)
+        return TabTag.select().where(
+            (TabTag.kind == kind_sig) & (TabTag.pid == '0000')
+        ).order_by(TabTag.order)
 
     @staticmethod
     def query_sub_cat(pid):
@@ -115,11 +116,13 @@ class MCategory(Mabc):
         Update the count of certain category.
         '''
 
-        entry2 = TabTag.update(count=TabPost2Tag.select().join(
-            TabPost, on=(TabPost.uid == TabPost2Tag.post_id)).where(
-                (TabPost.valid == 1)
-                & (TabPost2Tag.tag_id == cat_id)).count()).where(
-                    TabTag.uid == cat_id)
+        entry2 = TabTag.update(
+            count=TabPost2Tag.select().join(
+                TabPost, on=(TabPost.uid == TabPost2Tag.post_id)
+            ).where(
+                (TabPost.valid == 1) & (TabPost2Tag.tag_id == cat_id)
+            ).count()
+        ).where(TabTag.uid == cat_id)
         entry2.execute()
 
     @staticmethod
@@ -129,11 +132,10 @@ class MCategory(Mabc):
         '''
         raw_rec = TabTag.get(TabTag.uid == uid)
         entry = TabTag.update(
-            name=post_data['name'] if 'name' in post_data else raw_rec.name,
-            slug=post_data['slug'] if 'slug' in post_data else raw_rec.slug,
-            order=post_data['order']
-            if 'order' in post_data else raw_rec.order,
-            kind=post_data['kind'] if 'kind' in post_data else raw_rec.kind,
+            name=post_data.get('name', raw_rec.name),
+            slug=post_data.get('slug', raw_rec.slug),
+            order=post_data.get('order', raw_rec.order),
+            kind=post_data.get('kind', raw_rec.kind),
             pid=post_data['pid'],
         ).where(TabTag.uid == uid)
         entry.execute()
@@ -152,7 +154,7 @@ class MCategory(Mabc):
                 name=post_data['name'],
                 slug=post_data['slug'],
                 order=post_data['order'],
-                kind=post_data['kind'] if 'kind' in post_data else '1',
+                kind=post_data.get('kind', '1'),
                 pid=post_data['pid'],
             )
         return uid
