@@ -6,11 +6,10 @@ import time
 
 from config import CMS_CFG
 from torcms.core import tools
-from torcms.model.abc_model import Mabc
 from torcms.model.core_tab import TabCollect, TabPost
 
 
-class MCollect(Mabc):
+class MCollect():
     '''
     Model for collection.
     '''
@@ -88,6 +87,21 @@ class MCollect(Mabc):
                 timestamp=int(time.time()),
             )
 
+    @staticmethod
+    def remove_collect(user_id, app_id):
+        '''
+        Cancel collection
+        '''
+
+        rec = MCollect.get_by_signature(user_id, app_id)
+
+        if rec:
+            entry = TabCollect.delete().where(
+                TabCollect.uid == rec.uid)
+            entry.execute()
+        else:
+            return None
+
     @staticmethod
     def query_pager_by_userid(user_id, kind, num=10):
 
