@@ -78,13 +78,12 @@ class TabLink(BaseModel):
 
 
 class TabPost(BaseModel):
-    uid = peewee.CharField(
+    uid = peewee.TextField(
         null=False,
         index=True,
         unique=True,
         primary_key=True,
         default='00000',
-        max_length=5,
         help_text='',
     )
     title = peewee.CharField(null=False, help_text='Title')
@@ -115,8 +114,12 @@ class TabPost(BaseModel):
         null=False,
         max_length=1,
         default='1',
-        help_text='Post type: 1 for doc, 2 for inor',
+        help_text='Post type. According to the user defined.',
     )
+    state = peewee.CharField(null=False,
+                             max_length=4,
+                             default='0000',
+                             help_text='state for post. 发布/审核状态.')
     rating = peewee.FloatField(null=False,
                                default=5,
                                help_text='Rating of the post.')
@@ -178,9 +181,8 @@ class TabPostHist(BaseModel):
         max_length=255,
         help_text='',
     )
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
     user_name = peewee.CharField()
@@ -252,6 +254,15 @@ class TabMember(BaseModel):
                             default='1000',
                             help_text='Member Privilege',
                             max_length='4')
+    '''
+    进行审核的权限，与 role 配合使用。
+    role 声明是否有权限，    authority 声明对哪些 post 有权限。
+    post 权限类型由二进制的 '1', '10', '100', '1000', ... 声明 ，成员的 authority 则根据二进制相加的结果来声明多种 post 的审核权限
+    '''
+    authority = peewee.CharField(null=False,
+                            default='0',
+                            help_text='Member authority for checking',
+                            max_length='8')
     time_reset_passwd = peewee.IntegerField(null=False, default=0)
     time_login = peewee.IntegerField(null=False, default=0)
     time_create = peewee.IntegerField(null=False, default=0)
@@ -259,6 +270,8 @@ class TabMember(BaseModel):
     time_email = peewee.IntegerField(null=False,
                                      default=0,
                                      help_text='Time auto send email.')
+    failed_times = peewee.IntegerField(null=False, default=0, help_text='record the times for trying login.')
+    time_failed = peewee.IntegerField(null=False, default=0, help_text='timestamp for login failed.')
     extinfo = BinaryJSONField(null=False,
                               default={},
                               help_text='Extra data in JSON.')
@@ -315,9 +328,8 @@ class TabPost2Tag(BaseModel):
         max_length=4,
         help_text='',
     )
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
     order = peewee.IntegerField()
@@ -335,10 +347,9 @@ class TabReply(BaseModel):
         max_length=36,
         help_text='',
     )
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
         index=True,
-        max_length=5,
         help_text='',
     )
     user_id = peewee.CharField(
@@ -397,9 +408,8 @@ class TabCollect(BaseModel):
                            unique=True,
                            help_text='',
                            primary_key=True)
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
     user_id = peewee.CharField(
@@ -420,9 +430,8 @@ class TabEvaluation(BaseModel):
                            unique=True,
                            help_text='',
                            primary_key=True)
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
     user_id = peewee.CharField(
@@ -449,10 +458,9 @@ class TabRating(BaseModel):
         max_length=36,
         help_text='',
     )
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
         index=True,
-        max_length=5,
         help_text='',
     )
     rating = peewee.FloatField(null=False, )
@@ -469,9 +477,8 @@ class TabUsage(BaseModel):
                            unique=True,
                            help_text='',
                            primary_key=True)
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
     user_id = peewee.CharField(
@@ -490,18 +497,6 @@ class TabUsage(BaseModel):
     timestamp = peewee.IntegerField()
 
 
-# class TabAccess(BaseModel):
-#     '''
-#     Post访问情况， 按时间戳记录。此表与用户无关。
-#     ID 无法用时间戳，访问量大的情况下可能会相同。
-#     '''
-#     uid = peewee.BigIntegerField(null=False,
-#                               primary_key=True,
-#                               unique=True,
-#                               help_text='用时间时间戳作为ID')
-#     post_id = peewee.CharField(null=False, max_length=5, help_text='' )
-
-
 class TabRel(BaseModel):
     '''
     相关应用
@@ -512,14 +507,12 @@ class TabRel(BaseModel):
                            unique=True,
                            help_text='',
                            primary_key=True)
-    post_f_id = peewee.CharField(
+    post_f_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
-    post_t_id = peewee.CharField(
+    post_t_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
     count = peewee.IntegerField()
@@ -540,14 +533,12 @@ class TabCorrelation(BaseModel):
                            unique=True,
                            help_text='',
                            primary_key=True)
-    post_id = peewee.CharField(
+    post_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
-    rel_id = peewee.CharField(
+    rel_id = peewee.TextField(
         null=False,
-        max_length=5,
         help_text='',
     )
     kind = peewee.IntegerField()
@@ -622,7 +613,6 @@ class TabReferrer(BaseModel):
                            unique=True,
                            primary_key=True,
                            default='00000',
-                           max_length=5,
                            help_text='')
     media = peewee.CharField(null=False, help_text='来源')
     terminal = peewee.CharField(null=False, help_text='终端')
