@@ -4,17 +4,18 @@ For file entities. Just like pdf, zipfile, docx, etc.
 '''
 
 import time
-
+import datetime
 from config import CMS_CFG
 from torcms.core import tools
-from torcms.model.abc_model import Mabc, MHelper
+from torcms.model.abc_model import MHelper
 from torcms.model.core_tab import TabEntity, TabEntity2User, TabMember
 
 
-class MEntity2User(Mabc):
+class MEntity2User():
     '''
     For file entities. Just like pdf, zipfile, docx, etc.
     '''
+
     @staticmethod
     def get_by_uid(uid):
         return MHelper.get_by_uid(TabEntity2User, uid)
@@ -27,7 +28,7 @@ class MEntity2User(Mabc):
             TabEntity.kind.alias('entity_kind'),
         ).join(TabEntity,
                on=(TabEntity2User.entity_id == TabEntity.uid)).where(
-                   TabEntity.path == path)
+            TabEntity.path == path)
         return recs
 
     @staticmethod
@@ -39,12 +40,12 @@ class MEntity2User(Mabc):
         recs = TabEntity2User.select(
             TabEntity2User, TabEntity.path.alias('entity_path'),
             TabEntity.kind.alias('entity_kind')).join(
-                TabEntity,
-                on=(TabEntity2User.entity_id == TabEntity.uid)).join(
-                    TabMember,
-                    on=(TabEntity2User.user_id == TabMember.uid)).order_by(
-                        TabEntity2User.timestamp.desc()).paginate(
-                            current_page_num, CMS_CFG['list_num'])
+            TabEntity,
+            on=(TabEntity2User.entity_id == TabEntity.uid)).join(
+            TabMember,
+            on=(TabEntity2User.user_id == TabMember.uid)).order_by(
+            TabEntity2User.timestamp.desc()).paginate(
+            current_page_num, CMS_CFG['list_num'])
         return recs
 
     @staticmethod
@@ -55,10 +56,10 @@ class MEntity2User(Mabc):
             TabEntity.kind.alias('entity_kind'),
         ).join(TabEntity, on=(TabEntity2User.entity_id == TabEntity.uid)).join(
             TabMember, on=(TabEntity2User.user_id == TabMember.uid)).where(
-                TabEntity2User.user_id == userid).order_by(
-                    TabEntity2User.timestamp.desc(),
-                    TabEntity2User.entity_id).paginate(current_page_num,
-                                                       CMS_CFG['list_num'])
+            TabEntity2User.user_id == userid).order_by(
+            TabEntity2User.timestamp.desc(),
+            TabEntity2User.entity_id).paginate(current_page_num,
+                                               CMS_CFG['list_num'])
         return recs
 
     @staticmethod
@@ -85,6 +86,16 @@ class MEntity2User(Mabc):
         return TabEntity2User.select().where(
             TabEntity2User.user_id == userid).count()
 
+    @staticmethod
+    def total_number_by_year(year):
+        down_year = int(time.mktime(time.strptime(year, "%Y")))
+        next_year = str(int(year) + 1)
+        return TabEntity2User.select().where(
+            (TabEntity2User.timestamp >= down_year) & (
+                    TabEntity2User.timestamp < int(time.mktime(time.strptime(next_year, "%Y")))
+            )
+        ).count()
+
     @staticmethod
     def delete_by_uid(entity_uid):
         delete = TabEntity2User.delete().where(
