@@ -7,12 +7,11 @@ import peewee
 
 from config import CMS_CFG
 from torcms.core import tools
-from torcms.model.abc_model import Mabc
 from torcms.model.category_model import MCategory
 from torcms.model.core_tab import TabPost, TabPost2Tag, TabTag
 
 
-class MPost2Catalog(Mabc):
+class MPost2Catalog():
     '''
     Database Model for post to catalog.
     '''
@@ -182,6 +181,7 @@ class MPost2Catalog(Mabc):
         else:
             cat_con = TabPost2Tag.tag_id == cat_id
 
+
         if tag:
             condition = {'def_tag_arr': [tag]}
             recs = TabPost2Tag.select().join(
@@ -222,20 +222,20 @@ class MPost2Catalog(Mabc):
                     )).where(cat_con
                              & TabPost.extinfo.contains(condition)).order_by(
                                  TabPost.time_update.desc()).paginate(
-                                     current_page_num, CMS_CFG['list_num'])
+                                     current_page_num, CMS_CFG['list_num']).distinct()
         elif order:
             recs = TabPost.select().join(
                 TabPost2Tag,
                 on=((TabPost.uid == TabPost2Tag.post_id) &
                     (TabPost.valid == 1))).where(cat_con).order_by(
-                        TabPost.order.asc())
+                        TabPost.order.asc()).distinct()
         else:
             recs = TabPost.select().join(
                 TabPost2Tag,
                 on=((TabPost.uid == TabPost2Tag.post_id) &
                     (TabPost.valid == 1))).where(cat_con).order_by(
                         TabPost.time_update.desc()).paginate(
-                            current_page_num, CMS_CFG['list_num'])
+                            current_page_num, CMS_CFG['list_num']).distinct()
 
         return recs
 
