@@ -8,15 +8,16 @@ from datetime import datetime
 import peewee
 import tornado.escape
 
-from config import CMS_CFG, DB_CFG
+from config import CMS_CFG
+from torcms.core.tools import logger
 from torcms.core import tools
-from torcms.model.abc_model import Mabc, MHelper
+from torcms.model.abc_model import MHelper
 from torcms.model.core_tab import (TabCollect, TabEvaluation, TabPost,
                                    TabPost2Tag, TabPostHist, TabRating, TabRel,
                                    TabReply, TabUsage, TabUser2Reply)
 
 
-class MPost(Mabc):
+class MPost():
     '''
     Model for Posts.
     '''
@@ -97,16 +98,10 @@ class MPost(Mabc):
         update the kind of post.
         '''
 
-        entry = TabPost.update(kind=kind, ).where(TabPost.uid == uid)
+        entry = TabPost.update(kind=kind).where(TabPost.uid == uid)
         entry.execute()
         return True
 
-    @staticmethod
-    def update_field(uid, post_id=None):
-        if post_id:
-            entry = TabPost.update(uid=post_id).where(TabPost.uid == uid)
-            entry.execute()
-
     @staticmethod
     def update_cnt(uid, post_data):
         '''
@@ -117,7 +112,8 @@ class MPost(Mabc):
             cnt_html=tools.markdown2html(post_data['cnt_md']),
             user_name=post_data['user_name'],
             cnt_md=tornado.escape.xhtml_escape(post_data['cnt_md'].strip()),
-            time_update=tools.timestamp()).where(TabPost.uid == uid)
+            time_update=tools.timestamp()
+        ).where(TabPost.uid == uid)
         entry.execute()
 
     @staticmethod
@@ -128,105 +124,6 @@ class MPost(Mabc):
         entry = TabPost.update(order=order).where(TabPost.uid == uid)
         entry.execute()
 
-    @staticmethod
-    def update(uid, post_data, update_time=True):
-        '''
-        参数 `update_time` ， 是否更新时间。对于导入的数据，有时不需要更新。
-        '''
-
-        title = post_data['title'].strip()
-        if len(title) < 2:
-            return False
-        cnt_html = tools.markdown2html(post_data['cnt_md'])
-        # try:
-        #     if update_time:
-        #         entry2 = TabPost.update(
-        #             date=datetime.now(),
-        #             time_create=tools.timestamp()
-        #         ).where(TabPost.uid == uid)
-        #         entry2.execute()
-        # except:
-        #     pass
-        cur_rec = MPost.get_by_uid(uid)
-
-        if update_time:
-            entry = TabPost.update(
-                title=title,
-                user_name=post_data['user_name'],
-                cnt_md=tornado.escape.xhtml_escape(
-                    post_data['cnt_md'].strip()),
-                memo=post_data['memo'] if 'memo' in post_data else '',
-                cnt_html=cnt_html,
-                logo=post_data['logo'],
-                order=post_data['order'] if 'order' in post_data else '',
-                keywords=post_data['keywords']
-                if 'keywords' in post_data else '',
-                kind=post_data['kind'] if 'kind' in post_data else 1,
-                extinfo=post_data['extinfo']
-                if 'extinfo' in post_data else cur_rec.extinfo,
-                time_update=tools.timestamp(),
-                valid=post_data.get('valid', 1)).where(TabPost.uid == uid)
-        else:
-            entry = TabPost.update(
-                title=title,
-                user_name=post_data['user_name'],
-                cnt_md=tornado.escape.xhtml_escape(
-                    post_data['cnt_md'].strip()),
-                memo=post_data['memo'] if 'memo' in post_data else '',
-                cnt_html=cnt_html,
-                logo=post_data['logo'],
-                order=post_data['order'] if 'order' in post_data else '',
-                keywords=post_data['keywords'] if 'keywords' in post_data else '',
-                kind=post_data['kind'] if 'kind' in post_data else 1,
-                extinfo=post_data['extinfo']
-                if 'extinfo' in post_data else cur_rec.extinfo,
-                valid=post_data.get('valid', 1)).where(TabPost.uid == uid)
-        entry.execute()
-
-    @staticmethod
-    def add_or_update(uid, post_data, update_time=True):
-        '''
-        Add or update the post.
-        '''
-        cur_rec = MPost.get_by_uid(uid)
-        if cur_rec:
-            MPost.update(uid, post_data, update_time=update_time)
-        else:
-            MPost.create_post(uid, post_data)
-
-    @staticmethod
-    def create_post(post_uid, post_data):
-        '''
-        create the post.
-        '''
-        title = post_data['title'].strip()
-        if len(title) < 2:
-            return False
-
-        cur_rec = MPost.get_by_uid(post_uid)
-        if cur_rec:
-            return False
-
-        entry = TabPost.create(
-            title=title,
-            date=datetime.now(),
-            cnt_md=tornado.escape.xhtml_escape(post_data['cnt_md'].strip()),
-            cnt_html=tools.markdown2html(post_data['cnt_md']),
-            uid=post_uid,
-            time_create=post_data.get('time_create', tools.timestamp()),
-            time_update=post_data.get('time_update', tools.timestamp()),
-            user_name=post_data['user_name'],
-            view_count=post_data['view_count']
-            if 'view_count' in post_data else 1,
-            logo=post_data['logo'],
-            memo=post_data['memo'] if 'memo' in post_data else '',
-            order=post_data['order'] if 'order' in post_data else '',
-            keywords=post_data['keywords'] if 'keywords' in post_data else '',
-            extinfo=post_data['extinfo'] if 'extinfo' in post_data else {},
-            kind=post_data['kind'] if 'kind' in post_data else '1',
-            valid=post_data.get('valid', 1))
-        return entry.uid
-
     @staticmethod
     def query_cat_random(catid, **kwargs):
         '''
@@ -234,15 +131,19 @@ class MPost(Mabc):
         '''
         num = kwargs.get('limit', 8)
         if catid == '':
-            rand_recs = TabPost.select().where(TabPost.valid == 1).order_by(
-                peewee.fn.Random()).limit(num)
+            rand_recs = TabPost.select().where(
+                TabPost.valid == 1
+            ).order_by(
+                peewee.fn.Random()
+            ).limit(num)
         else:
             rand_recs = TabPost.select().join(
                 TabPost2Tag,
-                on=(TabPost.uid == TabPost2Tag.post_id
-                    )).where((TabPost.valid == 1)
-                             & (TabPost2Tag.tag_id == catid)).order_by(
-                peewee.fn.Random()).limit(num)
+                on=(TabPost.uid == TabPost2Tag.post_id)
+            ).where(
+                (TabPost.valid == 1) &
+                (TabPost2Tag.tag_id == catid)
+            ).order_by(peewee.fn.Random()).limit(num)
         return rand_recs
 
     @staticmethod
@@ -261,11 +162,14 @@ class MPost(Mabc):
         kind = kwargs.get('kind', None)
 
         if kind:
-            rand_recs = TabPost.select().where((TabPost.kind == kind) & (
-                    TabPost.valid == 1)).order_by(peewee.fn.Random()).limit(limit)
+            rand_recs = TabPost.select().where(
+                (TabPost.kind == kind) &
+                (TabPost.valid == 1)
+            ).order_by(peewee.fn.Random()).limit(limit)
         else:
-            rand_recs = TabPost.select().where(TabPost.valid == 1).order_by(
-                peewee.fn.Random()).limit(limit)
+            rand_recs = TabPost.select().where(
+                TabPost.valid == 1
+            ).order_by(peewee.fn.Random()).limit(limit)
         return rand_recs
 
     @staticmethod
@@ -278,21 +182,28 @@ class MPost(Mabc):
         if order_by_create:
             if kind:
                 recent_recs = TabPost.select().where(
-                    (TabPost.kind == kind) & (TabPost.valid == 1)).order_by(
-                    TabPost.time_create.desc()).limit(num)
+                    (TabPost.kind == kind) & (TabPost.valid == 1)
+                ).order_by(
+                    TabPost.time_create.desc()
+                ).limit(num)
             else:
                 recent_recs = TabPost.select().where(
-                    TabPost.valid == 1).order_by(
-                    TabPost.time_create.desc()).limit(num)
+                    TabPost.valid == 1
+                ).order_by(
+                    TabPost.time_create.desc()
+                ).limit(num)
         else:
             if kind:
                 recent_recs = TabPost.select().where(
-                    (TabPost.kind == kind) & (TabPost.valid == 1)).order_by(
+                    (TabPost.kind == kind) & (TabPost.valid == 1)
+                ).order_by(
                     TabPost.time_update.desc()).limit(num)
             else:
                 recent_recs = TabPost.select().where(
-                    TabPost.valid == 1).order_by(
-                    TabPost.time_update.desc()).limit(num)
+                    TabPost.valid == 1
+                ).order_by(
+                    TabPost.time_update.desc()
+                ).limit(num)
         return recent_recs
 
     @staticmethod
@@ -304,43 +215,54 @@ class MPost(Mabc):
         limit = kwargs.get('limit', 10)
 
         return TabPost.select().where(
-            (TabPost.kind == kind) & (TabPost.valid == 1)).order_by(
-            TabPost.time_update.desc()).limit(limit)
+            (TabPost.kind == kind) & (TabPost.valid == 1)
+        ).order_by(
+            TabPost.time_update.desc()
+        ).limit(limit)
 
     @staticmethod
     def query_keywords_empty(kind='1'):
         '''
         Query keywords, empty.
         '''
-        return TabPost.select().where((TabPost.kind == kind)
-                                      & (TabPost.keywords == ''))
+        return TabPost.select().where(
+            (TabPost.kind == kind) & (TabPost.keywords == '')
+        )
 
     @staticmethod
     def query_recent_edited(timstamp, kind='1'):
         '''
         获取最近更新的Post，以时间戳为条件
         '''
-        return TabPost.select().where((TabPost.kind == kind) & (
-                TabPost.time_update > timstamp)).order_by(
-            TabPost.time_update.desc())
+        return TabPost.select().where(
+            (TabPost.kind == kind) &
+            (TabPost.time_update > timstamp)
+        ).order_by(
+            TabPost.time_update.desc()
+        )
 
     @staticmethod
     def query_dated(num=8, kind='1'):
         '''
         获取久未更新的Post列表。
         '''
-        return TabPost.select().where((TabPost.kind == kind)
-                                      & (TabPost.valid == 1)).order_by(
-            TabPost.time_update.asc()).limit(num)
+        return TabPost.select().where(
+            (TabPost.kind == kind) &
+            (TabPost.valid == 1)
+        ).order_by(
+            TabPost.time_update.asc()
+        ).limit(num)
 
     @staticmethod
     def query_most_pic(num, kind='1'):
         '''
         Query most pics.
         '''
-        return TabPost.select().where((TabPost.kind == kind)
-                                      & (TabPost.logo != "")
-                                      & (TabPost.valid == 1)).order_by(
+        return TabPost.select().where(
+            (TabPost.kind == kind) &
+            (TabPost.logo != "") &
+            (TabPost.valid == 1)
+        ).order_by(
             TabPost.view_count.desc()).limit(num)
 
     @staticmethod
@@ -350,31 +272,35 @@ class MPost(Mabc):
         '''
 
         if label:
-            recent_recs = MPost.query_cat_recent_with_label(cat_id,
-                                                            label=label,
-                                                            num=num,
-                                                            kind=kind,
-                                                            order=order)
+            recent_recs = MPost.query_cat_recent_with_label(
+                cat_id,
+                label=label,
+                num=num,
+                kind=kind,
+                order=order
+            )
         else:
-            recent_recs = MPost.query_cat_recent_no_label(cat_id,
-                                                          num=num,
-                                                          kind=kind,
-                                                          order=order)
+            recent_recs = MPost.query_cat_recent_no_label(
+                cat_id,
+                num=num,
+                kind=kind,
+                order=order
+            )
         return recent_recs
 
     @staticmethod
     def query_by_tag(cat_id, kind='1'):
         '''
-        Query recent posts of catalog.
-        ToDo: kind ?
+        Query posts of catalog.
         '''
 
         return TabPost.select().join(
-            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id
-                             )).where((TabPost.kind == kind)
-                                      & (TabPost2Tag.tag_id == cat_id)
-                                      & (TabPost.valid == 1)).order_by(
-            TabPost.time_create.desc())
+            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id)
+        ).where(
+            (TabPost.kind == kind) & (TabPost2Tag.tag_id == cat_id) & (TabPost.valid == 1)
+        ).order_by(
+            TabPost.time_create.desc()
+        )
 
     @staticmethod
     def query_by_parid(par_id, kind='9'):
@@ -382,12 +308,16 @@ class MPost(Mabc):
         Query recent posts of catalog.
 
         '''
+
         return TabPost.select().join(
-            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id
-                             )).where((TabPost.kind == kind)
-                                      & (TabPost2Tag.par_id == par_id)
-                                      & (TabPost.valid == 1)).order_by(
-            TabPost.time_create.desc())
+            TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id)
+        ).where(
+            (TabPost.kind == kind) &
+            (TabPost2Tag.par_id == par_id) &
+            (TabPost.valid == 1)
+        ).order_by(
+            TabPost.time_create.desc()
+        )
 
     @staticmethod
     def query_cat_recent_with_label(cat_id,
@@ -401,7 +331,7 @@ class MPost(Mabc):
         if order:
             sort_criteria = TabPost.order.asc()
         else:
-            sort_criteria = TabPost.time_create.desc()
+            sort_criteria = TabPost.time_update.desc()
 
         return TabPost.select().join(
             TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id)).where(
@@ -418,7 +348,7 @@ class MPost(Mabc):
         if order:
             sort_criteria = TabPost.order.asc()
         else:
-            sort_criteria = TabPost.time_create.desc()
+            sort_criteria = TabPost.time_update.desc()
 
         return TabPost.select().join(
             TabPost2Tag, on=(TabPost.uid == TabPost2Tag.post_id)).where(
@@ -547,9 +477,9 @@ class MPost(Mabc):
         '''
         Get All the records.
         '''
-        return TabPost.select().where((TabPost.kind == kind)
-                                      & (TabPost.valid == 1)).order_by(
-            TabPost.time_update.desc())
+        return TabPost.select().where(
+            (TabPost.kind == kind) & (TabPost.valid == 1)
+        ).order_by(TabPost.time_update.desc())
 
     @staticmethod
     def update_jsonb(uid, extinfo):
@@ -557,64 +487,99 @@ class MPost(Mabc):
         Update the json.
         '''
         cur_extinfo = MPost.get_by_uid(uid).extinfo
-        for key in extinfo:
-            cur_extinfo[key] = extinfo[key]
-        entry = TabPost.update(extinfo=cur_extinfo, ).where(TabPost.uid == uid)
+        cur_extinfo.update(extinfo)
+        entry = TabPost.update(extinfo=cur_extinfo).where(TabPost.uid == uid)
         entry.execute()
         return uid
 
     @staticmethod
-    def modify_meta(uid, data_dic, extinfo=None):
+    def add_or_update(uid, post_data, update_time=None):
+        '''
+        Add or update the post.
+        '''
+        uid = MPost.add_or_update_post(uid, post_data)
+        return uid
+
+    @staticmethod
+    def add_or_update_post(uid, post_data, extinfo=None):
         '''
         update meta of the rec.
         '''
-        if extinfo is None:
-            extinfo = {}
-        title = data_dic['title'].strip()
-        # if len(title) < 2:
-        #     return False
+        if len(uid) < 4:
+            return False
+        title = post_data['title'].strip()
+        if len(title) < 2:
+            return False
+        post_data['title'] = title
+
+        post_extdata = post_data.get('extinfo', {})
+        if extinfo:
+            post_extdata.update(extinfo)
 
         cur_info = MPost.get_by_uid(uid)
-        if cur_info:
 
+        if cur_info:
             cur_extinfo = cur_info.extinfo
             # Update the extinfo, Not replace
-            for key in extinfo:
-                cur_extinfo[key] = extinfo[key]
-            cur_extinfo['def_editor_name'] = data_dic['user_name'].strip()
-            entry = TabPost.update(
-                title=title,
-                # user_name=data_dic['user_name'],
-                keywords='',
-                time_update=tools.timestamp(),
-                date=datetime.now(),
-                cnt_md=data_dic['cnt_md'],
-                memo=data_dic['memo'] if 'memo' in data_dic else '',
-                logo=data_dic['logo'],
-                order=data_dic['order'] if 'order' in data_dic else '',
-                cnt_html=tools.markdown2html(data_dic['cnt_md']),
-                extinfo=cur_extinfo,
-                valid=data_dic['valid']).where(TabPost.uid == uid)
-            entry.execute()
+            cur_extinfo.update(post_extdata)
+            cur_extinfo['def_editor_name'] = post_data['user_name'].strip()
+
+            MPost.__update_post(uid, post_data, cur_extinfo)
         else:
-            return MPost.add_meta(uid, data_dic, extinfo)
+            MPost.__add_post(uid, post_data, post_extdata)
         return uid
 
+    #
+    # @staticmethod
+    # def __update_post(uid, post_data, update_time=False):
+    #     '''
+    #     参数 `update_time` ， 是否更新时间。对于导入的数据，有时不需要更新。
+    #     '''
+    #
+    #
+    #     # cnt_html = tools.markdown2html(post_data['cnt_md'])
+    #
+    #     cur_rec = MPost.get_by_uid(uid)
+    #
+    #     entry = TabPost.update(
+    #         # title='',
+    #         # user_name=post_data['user_name'],
+    #         # cnt_md=tornado.escape.xhtml_escape(post_data['cnt_md'].strip()),
+    #         # memo=post_data['memo'] if 'memo' in post_data else '',
+    #         # cnt_html=cnt_html,
+    #         # logo=post_data['logo'],
+    #         # order=post_data['order'] if 'order' in post_data else '',
+    #
+    #         # kind=post_data['kind'] if 'kind' in post_data else 1,
+    #         # extinfo=post_data['extinfo'] if 'extinfo' in post_data else cur_rec.extinfo,
+    #         # time_update=tools.timestamp(),
+    #         # valid=post_data.get('valid', 1)
+    #     ).where(TabPost.uid == uid)
+    #
+    #     entry.execute()
+    #     return uid
+
     @staticmethod
-    def modify_init(uid, data_dic):
+    def __update_post(uid, post_data, cur_extinfo):
         '''
-        update when init.
+        注意，不更新 kind
         '''
-        postinfo = MPost.get_by_uid(uid)
         entry = TabPost.update(
+            title=post_data['title'].strip(),
+            # user_name=data_dic['user_name'],
+            keywords=post_data['keywords'] if 'keywords' in post_data else '',
             time_update=tools.timestamp(),
             date=datetime.now(),
-            kind=data_dic['kind'] if 'kind' in data_dic else postinfo.kind,
-            keywords=data_dic['keywords']
-            if 'keywords' in data_dic else postinfo.keywords,
+            # cnt_md=post_data['cnt_md'],
+            cnt_md=tornado.escape.xhtml_escape(post_data['cnt_md'].strip()),
+            memo=post_data.get('memo', ''),
+            logo=post_data.get('logo', '').strip(),
+            order=post_data.get('order', ''),
+            cnt_html=tools.markdown2html(post_data['cnt_md']),
+            extinfo=cur_extinfo,
+            valid=post_data.get('valid', 1)
         ).where(TabPost.uid == uid)
         entry.execute()
-        return uid
 
     @staticmethod
     def query_most_by_cat(num=8, catid=None, kind='2'):
@@ -647,16 +612,23 @@ class MPost(Mabc):
         '''
         根据关键字对标题进行检索
         '''
-        return TabPost.select().where((TabPost.kind == kind) & (
-                TabPost.valid == 1) & (TabPost.title.contains(par2))).order_by(
-            TabPost.time_update.desc()).limit(20)
+        return TabPost.select().where(
+            (TabPost.kind == kind) &
+            (TabPost.valid == 1) &
+            (TabPost.title.contains(par2))
+        ).order_by(
+            TabPost.time_update.desc()
+        ).limit(20)
 
     @staticmethod
     def query_extinfo_by_cat(cat_id, kind='2'):
         return TabPost.select().where(
-            (TabPost.kind == kind) & (TabPost.valid == 1)
-            & (TabPost.extinfo['def_cat_uid'] == cat_id)).order_by(
-            TabPost.time_update.desc())
+            (TabPost.kind == kind) &
+            (TabPost.valid == 1) &
+            (TabPost.extinfo['def_cat_uid'] == cat_id)
+        ).order_by(
+            TabPost.time_update.desc()
+        )
 
     @staticmethod
     def query_by_extinfo(key='', val=''):
@@ -664,7 +636,8 @@ class MPost(Mabc):
         根据扩展字段查询
         '''
         return TabPost.select().where(
-            (TabPost.extinfo[key] == val)).order_by(TabPost.time_update.desc())
+            (TabPost.extinfo[key] == val)
+        ).order_by(TabPost.time_update.desc())
 
     @staticmethod
     def query_by_tagname(tag_name, kind='2'):
@@ -672,56 +645,50 @@ class MPost(Mabc):
         根据标签进行查询
         '''
         return TabPost.select().where(
-            (TabPost.kind == kind) & (TabPost.valid == 1)
-            & (TabPost.extinfo['def_tag_arr'].contains(tag_name))).order_by(
+            (TabPost.kind == kind) &
+            (TabPost.valid == 1) &
+            (TabPost.extinfo['def_tag_arr'].contains(tag_name))
+        ).order_by(
             TabPost.time_update.desc())
 
-    @staticmethod
-    def get_label_fenye(tag_slug, _idx):
-        all_list = MPost.query_by_tagname(tag_slug)
-        # 当前分页的记录
-        # Todo
-        # current_list = all_list[(idx - 1) * CMS_CFG['list_num']: idx * CMS_CFG['list_num']]
-        return all_list
-
     @staticmethod
     def query_pager_by_tag(tag, current_page_num=1, kind='2'):
-        recs = MPost.query_by_tagname(tag,
-                                      kind).paginate(current_page_num,
-                                                     CMS_CFG['list_num'])
+        recs = MPost.query_by_tagname(
+            tag,
+            kind
+        ).paginate(
+            current_page_num,
+            CMS_CFG['list_num']
+        )
         return recs
 
     @staticmethod
-    def add_meta(uid, data_dic, extinfo=None):
+    def __add_post(uid, post_data, extinfo=None):
         '''
         adding meta for post.
         '''
 
         if extinfo is None:
             extinfo = {}
-        if len(uid) < 4:
-            return False
-        title = data_dic['title'].strip()
-        # if len(title) < 2:
-        #     return False
+
         TabPost.create(
             uid=uid,
-            title=title,
-            keywords='',
-            time_create=tools.timestamp(),
-            time_update=tools.timestamp(),
-            create_time=tools.timestamp(),
+            title=post_data['title'],
+            keywords=post_data.get('keywords', ''),
+            time_create=post_data.get('time_create', tools.timestamp()),
+            time_update=post_data.get('time_update', tools.timestamp()),
             date=datetime.now(),
-            cnt_md=data_dic['cnt_md'].strip(),
-            memo=data_dic['memo'] if 'memo' in data_dic else '',
-            logo=data_dic['logo'].strip(),
-            order=data_dic['order'] if 'order' in data_dic else '',
-            cnt_html=tools.markdown2html(data_dic['cnt_md']),
-            view_count=0,
+            cnt_md=tornado.escape.xhtml_escape(post_data['cnt_md'].strip()),
+            memo=post_data.get('memo', ''),
+            logo=post_data.get('logo', '').strip(),
+            order=post_data.get('order', ''),
+            state=post_data.get('state', 'a000'),
+            cnt_html=tools.markdown2html(post_data['cnt_md']),
+            view_count=post_data.get('view_count', 1),
             extinfo=extinfo,
-            user_name=data_dic['user_name'],
-            valid=data_dic['valid'] if 'valid' in data_dic else 1,
-            kind=data_dic['kind'],
+            user_name=post_data['user_name'],
+            valid=post_data.get('valid', 1),
+            kind=post_data.get('kind', '1'),
         )
         return uid
 
@@ -730,10 +697,8 @@ class MPost(Mabc):
         '''
         Get All data of certain kind according to the condition
         '''
-        if DB_CFG['kind'] == 's':
-            return TabPost.select().where((TabPost.kind == kind)
-                                          & (TabPost.valid == 1)).order_by(
-                TabPost.time_update.desc())
+
+        logger.info(f'TorCMS:: condition: {condition}')
 
         if sort_option:
             if sort_option == 'time_update':
@@ -752,8 +717,8 @@ class MPost(Mabc):
             sort_criteria = TabPost.time_update.desc()
 
         return TabPost.select().where(
-            (TabPost.kind == kind) & (TabPost.valid == 1)
-            & TabPost.extinfo.contains(condition)).order_by(sort_criteria)
+            (TabPost.kind == kind) & (TabPost.valid == 1) & TabPost.extinfo.contains(condition)
+        ).order_by(sort_criteria)
 
     @staticmethod
     def get_num_condition(con):
@@ -763,51 +728,23 @@ class MPost(Mabc):
         return MPost.query_under_condition(con).count()
 
     @staticmethod
-    def addata_init(data_dic, ext_dic=None):
-        if ext_dic is None:
-            ext_dic = {}
-
-        if len(data_dic['sig']) < 4:
-            return False
-        title = data_dic['title'].strip()
-        if len(title) < 2:
-            return False
-
-        postinfo = MPost.get_by_uid(data_dic['sig'])
-        if postinfo:
-
-            if data_dic['title'] == postinfo.title and data_dic['kind'] == postinfo.kind:
-                pass
-            else:
-                MPost.modify_init(data_dic['sig'], data_dic)
-        else:
-            time_stamp = int(time.time())
-
-            TabPost.create(
-                uid=data_dic['sig'],
-                title=data_dic['title'],
-                time_create=time_stamp,
-                time_update=time_stamp,
-                cnt_md=data_dic['cnt_md'] if 'memo' in data_dic else '',
-                memo=data_dic['memo'] if 'memo' in data_dic else '',
-                cnt_html=data_dic['cnt_html'],
-                date=datetime.now(),
-                keywords='',
-                view_count=0,
-                extinfo=ext_dic)
-
-    @staticmethod
-    def query_list_pager(con, idx, kind='2', sort_option=''):
+    def query_list_pager(con, idx, kind='2', sort_option='', list_num=''):
         '''
         Get records of certain pager.
         '''
+
         if sort_option:
             recs = MPost.query_under_condition(con,
                                                kind=kind,
                                                sort_option=sort_option)
         else:
             recs = MPost.query_under_condition(con, kind=kind)
-        return recs[(idx - 1) * CMS_CFG['list_num']:idx * CMS_CFG['list_num']]
+        if list_num:
+            list_num = list_num
+        else:
+            list_num = CMS_CFG['list_num']
+
+        return recs[(int(idx) - 1) * int(list_num):int(idx) * int(list_num)]
 
     @staticmethod
     def count_of_certain_kind(kind):
@@ -871,3 +808,96 @@ class MPost(Mabc):
         except Exception as err:
             print(repr(err))
             return False
+
+    @staticmethod
+    def update_valid(uid):
+
+        entry = TabPost.update(valid=1).where(TabPost.uid == uid)
+
+        try:
+            entry.execute()
+            return True
+        except Exception as err:
+            print(repr(err))
+            return False
+
+    @staticmethod
+    def update_state(uid, state):
+        '''
+        更新审核状态
+        '''
+        try:
+            entry = TabPost.update(
+                state=state
+            ).where(TabPost.uid == uid)
+            entry.execute()
+            return True
+        except Exception as err:
+            print(repr(err))
+            return False
+
+    @staticmethod
+    def query_by_state(state, kind, current_page_num=1):
+        if state:
+            recent_recs = TabPost.select().where(
+                TabPost.state.endswith(state) & (TabPost.kind == kind)
+            ).order_by(
+                TabPost.time_create.desc()
+            ).paginate(
+                current_page_num,
+                CMS_CFG['list_num']
+            )
+        else:
+            recent_recs = TabPost.select().where(TabPost.kind == kind).order_by(
+                TabPost.time_create.desc()).paginate(
+                current_page_num,
+                CMS_CFG['list_num'])
+
+        return recent_recs
+
+    @staticmethod
+    def count_of_certain_by_state(state, kind):
+        if state:
+            recs = TabPost.select().where(
+                TabPost.state.endswith(state) & (TabPost.kind == kind)
+            )
+        else:
+            recs = TabPost.select().where(TabPost.kind == kind)
+        return recs.count()
+
+    @staticmethod
+    def query_by_username(username, state, kind, current_page_num=1):
+        if state:
+            recent_recs = TabPost.select().where(
+                (TabPost.user_name == username) &
+                (TabPost.state.endswith(state)) &
+                (TabPost.kind == kind)
+            ).order_by(
+                TabPost.time_create.desc()
+            ).paginate(
+                current_page_num,
+                CMS_CFG['list_num']
+            )
+        else:
+            recent_recs = TabPost.select().where(
+                (TabPost.user_name == username) & (TabPost.kind == kind)
+            ).order_by(
+                TabPost.time_create.desc()
+            ).paginate(
+                current_page_num,
+                CMS_CFG['list_num']
+            )
+        return recent_recs
+
+    @staticmethod
+    def count_of_certain_by_username(username, state, kind):
+        if state:
+            recs = TabPost.select().where(
+                (TabPost.user_name == username) &
+                (TabPost.state.endswith(state)) &
+                (TabPost.kind == kind)
+            )
+        else:
+            recs = TabPost.select().where(
+                (TabPost.user_name == username) & (TabPost.kind == kind))
+        return recs.count()
