@@ -3,13 +3,12 @@
 import peewee
 
 from torcms.core import tools
-from torcms.model.abc_model import Mabc
 from torcms.model.core_tab import TabPost, TabPost2Tag, TabRel, TabCorrelation
 from torcms.model.label_model import MPost2Label
 from torcms.model.post2catalog_model import MPost2Catalog as MInfor2Catalog
 
 
-class MCorrelation(Mabc):
+class MCorrelation():
     @staticmethod
     def add_relation(postid, relid, kind, order):
         '''
@@ -75,13 +74,13 @@ class MCorrelation(Mabc):
         recs = TabCorrelation.select().where(
             (TabCorrelation.post_id == app_id) &
             (TabCorrelation.kind == kind)
-        ).order_by(
-            TabCorrelation.order
+        ).distinct(TabCorrelation.rel_id).order_by(
+            TabCorrelation.rel_id
         ).limit(num)
         return recs
 
 
-class MRelation(Mabc):
+class MRelation():
     @staticmethod
     def add_relation(app_f, app_t, weight=1):
         '''
@@ -131,7 +130,8 @@ class MRelation(Mabc):
     @staticmethod
     def get_app_relations(app_id, num=20, kind='1'):
         '''
-        The the related infors. 如有标签按标签推荐，如无标签按分类推荐
+        The the related infors.
+        如有标签按标签推荐，如无标签按分类推荐
         '''
 
         tag_info = filter(lambda x: not x.tag_name.startswith('_'),
@@ -173,19 +173,33 @@ class MRelation(Mabc):
                 ).limit(num)
 
         else:
-
-            recs = TabPost2Tag.select(
-                TabPost2Tag,
-                TabPost.title.alias('post_title'),
-                TabPost.valid.alias('post_valid')
-            ).join(
-                TabPost, on=(TabPost2Tag.post_id == TabPost.uid)
-            ).where(
-                (TabPost.uid != app_id) &
-                (TabPost2Tag.tag_id == info_tag.tag_id) &
-                (TabPost.kind == kind) &
-                (TabPost.valid == 1)
-            ).order_by(
-                peewee.fn.Random()
-            ).limit(num)
+            if info_tag:
+                recs = TabPost2Tag.select(
+                    TabPost2Tag,
+                    TabPost.title.alias('post_title'),
+                    TabPost.valid.alias('post_valid')
+                ).join(
+                    TabPost, on=(TabPost2Tag.post_id == TabPost.uid)
+                ).where(
+                    (TabPost.uid != app_id) &
+                    (TabPost2Tag.tag_id == info_tag.tag_id) &
+                    (TabPost.kind == kind) &
+                    (TabPost.valid == 1)
+                ).order_by(
+                    peewee.fn.Random()
+                ).limit(num)
+            else:
+                recs = TabPost2Tag.select(
+                    TabPost2Tag,
+                    TabPost.title.alias('post_title'),
+                    TabPost.valid.alias('post_valid')
+                ).join(
+                    TabPost, on=(TabPost2Tag.post_id == TabPost.uid)
+                ).where(
+                    (TabPost.uid != app_id) &
+                    (TabPost.kind == kind) &
+                    (TabPost.valid == 1)
+                ).order_by(
+                    peewee.fn.Random()
+                ).limit(num)
         return recs
