@@ -9,12 +9,11 @@ import peewee
 
 from torcms.core import tools
 from torcms.core.tools import logger
-from torcms.model.abc_model import Mabc
 from torcms.model.core_tab import TabPost, TabUsage
 from torcms.model.post2catalog_model import MPost2Catalog as MInfor2Catalog
 
 
-class MUsage(Mabc):
+class MUsage():
     '''
     Handle the usage of the info.
     '''
