@@ -6,14 +6,14 @@ import time
 
 from config import CMS_CFG
 from torcms.core import tools
-from torcms.model.abc_model import Mabc
 from torcms.model.core_tab import TabMember
 
 
-class MUser(Mabc):
+class MUser():
     '''
     Model for user.
     '''
+
     @staticmethod
     def query_all(limit=50):
         '''
@@ -80,31 +80,55 @@ class MUser(Mabc):
     def check_user_by_name(user_name, u_pass):
         '''
         Checking the password by user's name.
+
+        1: for success
+        0: for failure
+        2: for forbidden.
+        -1: for no user
         '''
         the_query = TabMember.select().where(TabMember.user_name == user_name)
         if the_query.count() == 0:
             return -1
 
         the_user = the_query.get()
+        failed_times = the_user.failed_times
+        time_failed = the_user.time_failed
+        c_tiemstamp = tools.timestamp()
+
+        # 测试是否限制登录
+        if c_tiemstamp - time_failed > 1 * 60 * 60:
+            # 如果距离上次登录失败超过1小时，则重置
+            # Set the failed times to 0.
+            entry2 = TabMember.update(failed_times=0).where(
+                TabMember.user_name == user_name)
+            try:
+                entry2.execute()
+            except Exception as err:
+                print(repr(err))
+        elif failed_times > 4:
+            return 2
+        else:
+            pass
+
         if the_user.user_pass == tools.md5(u_pass):
             return 1
         return 0
 
-    @staticmethod
-    def check_user_by_email(user_email, u_pass):
-        '''
-        Checking the password by user's email.
-        '''
-
-        the_query = TabMember.select().where(
-            TabMember.user_email == user_email)
-        if the_query.count() == 0:
-            return -1
-
-        the_user = the_query.get()
-        if the_user.user_pass == tools.md5(u_pass):
-            return 1
-        return 0
+    # @staticmethod
+    # def check_user_by_email(user_email, u_pass):
+    #     '''
+    #     Checking the password by user's email.
+    #     '''
+    #
+    #     the_query = TabMember.select().where(
+    #         TabMember.user_email == user_email)
+    #     if the_query.count() == 0:
+    #         return -1
+    #
+    #     the_user = the_query.get()
+    #     if the_user.user_pass == tools.md5(u_pass):
+    #         return 1
+    #     return 0
 
     @staticmethod
     def update_pass(user_id, newpass):
@@ -200,11 +224,51 @@ class MUser(Mabc):
             return False
 
     @staticmethod
-    def update_role(u_name, newprivilege):
+    def update_failed_info(user_name):
+        '''
+        Update the time when user reset passwd.
+        '''
+
+        # First: get the user.
+        recs = TabMember.select().where(TabMember.user_name == user_name)
+
+        if recs:
+            rec = recs.get()
+            old_time = rec.failed_times
+        else:
+            return False
+
+        #  Second: upate failed times.
+        entry = TabMember.update(failed_times=old_time + 1).where(
+            TabMember.user_name == user_name)
+        try:
+            entry.execute()
+            # return True
+        except Exception as err:
+            print(repr(err))
+            return False
+
+        # Third: Set timestamp that failed.
+        entry2 = TabMember.update(
+            time_failed=tools.timestamp()
+        ).where(
+            TabMember.user_name == user_name)
+        try:
+            entry2.execute()
+
+        except Exception as err:
+            print(repr(err))
+            return False
+        return True
+
+    @staticmethod
+    def update_role(u_name, postdata):
         '''
         Update the role of the usr.
         '''
-        entry = TabMember.update(role=newprivilege).where(
+        role = postdata['role']
+        authority = postdata.get('authority','0')
+        entry = TabMember.update(role=role, authority=authority).where(
             TabMember.user_name == u_name)
         try:
             entry.execute()
@@ -214,14 +278,25 @@ class MUser(Mabc):
             return False
 
     @staticmethod
-    def update_time_login(u_name):
+    def update_success_info(u_name):
         '''
         Update the login time for user.
         '''
+        # First, record the time that logged in.
         entry = TabMember.update(time_login=tools.timestamp()).where(
             TabMember.user_name == u_name)
         entry.execute()
 
+        # Second , set the failed times to 0.
+        entry2 = TabMember.update(failed_times=0).where(
+            TabMember.user_name == u_name)
+        try:
+            entry2.execute()
+        except Exception as err:
+            print(repr(err))
+            return False
+        return True
+
     @staticmethod
     def create_user(post_data, extinfo=None):
         '''
@@ -244,10 +319,16 @@ class MUser(Mabc):
             out_dic['code'] = '11'
             return out_dic
 
+
         if not tools.check_email_valid(post_data['user_email']):
             out_dic['code'] = '21'
             return out_dic
 
+        if not tools.check_pass_valid(post_data['user_pass']):
+            out_dic['code'] = '41'
+            return out_dic
+
+
         if MUser.get_by_email(post_data['user_email']):
             out_dic['code'] = '31'
             return out_dic
@@ -261,7 +342,7 @@ class MUser(Mabc):
                 user_name=post_data['user_name'],
                 user_pass=tools.md5(post_data['user_pass']),
                 user_email=post_data['user_email'],
-                role='1000',  # ‘1000' as default role.
+                role=post_data.get('role','1000'),  # ‘1000' as default role.
                 time_create=tools.timestamp(),
                 time_update=tools.timestamp(),
                 time_reset_passwd=tools.timestamp(),
@@ -342,7 +423,7 @@ class MUser(Mabc):
 
         return TabMember.select().where(
             TabMember.time_create > time_that).order_by(
-                TabMember.time_create.desc())
+            TabMember.time_create.desc())
 
     @staticmethod
     def query_pager_by_time(current_page_num=1):
