@@ -12,11 +12,11 @@ import tornado.escape
 from config import CMS_CFG
 from torcms.core import tools
 from torcms.core.tools import logger
-from torcms.model.abc_model import Mabc, MHelper
+from torcms.model.abc_model import MHelper
 from torcms.model.core_tab import TabWiki
 
 
-class MWiki(Mabc):
+class MWiki():
     '''
     Class for wiki.
     '''
