@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 '''
-TorCMS 基本模块
+TorCMS basic modules.
 '''
 
 from math import ceil as math_ceil
@@ -8,10 +8,7 @@ from math import ceil as math_ceil
 import bs4
 import tornado.escape
 import tornado.web
-
-import config
 from torcms.core.tool.whoosh_tool import YunSearch
-from torcms.core.tools import logger
 from torcms.model.category_model import MCategory
 from torcms.model.collect_model import MCollect
 from torcms.model.comment_model import MComment
@@ -27,12 +24,15 @@ from torcms.model.reply2user_model import MReply2User
 from torcms.model.reply_model import MReply
 from torcms.model.user_model import MUser
 from torcms.model.wiki_model import MWiki
+from config import router_post
+import config
 
 
 class ShowPage(tornado.web.UIModule):
     '''
     Get page info by page_id.
     '''
+
     def render(self, *args, **kwargs):
         '''
         '''
@@ -42,7 +42,7 @@ class ShowPage(tornado.web.UIModule):
         page = MWiki.get_by_uid(page_id)
         kwd = {'uid': page_id, 'count': count}
         if page:
-            out_str = self.render_string('modules/show_page.html',
+            out_str = self.render_string('modules/post/show_page.html',
                                          postinfo=page,
                                          userinfo=userinfo,
                                          kwd=kwd)
@@ -51,58 +51,45 @@ class ShowPage(tornado.web.UIModule):
         return out_str
 
 
-class PostListOfTag(tornado.web.UIModule):
-    def render(self, *args, **kwargs):
-        tagid = args[0]
-        posts = MPost.query_by_tag(tagid, kind='5')
-        outstr = ''
-        for postinfo in posts:
-            tmpl = '''<li class ="list-group-item" ><a href="/course/{uid}">{title}</a></li>
-            '''.format(title=postinfo.title, uid=postinfo.uid)
-            outstr = outstr + tmpl
-        return outstr
-
-
 class PostLabels(tornado.web.UIModule):
     '''
     Show the labels of the post.
     '''
+
     def render(self, *args, **kwargs):
-        postinfo = kwargs.get('postinfo', None)
-        if postinfo:
+
+        post_uid = kwargs.get('post_uid', None)
+
+        if post_uid:
+
+            postinfo = MPost.get_by_uid(post_uid)
+            kind = postinfo.kind
             tag_info = filter(lambda x: not x.tag_name.startswith('_'),
                               MPost2Label.get_by_uid(postinfo.uid).objects())
-            idx = 1
-            outstr = '<span class="post_label">'
-            for tag in tag_info:
-                outstr += '''<a href="/label/{kind}/{tag_uid}"
-                    class ="app_label tag{index}"> {tag_name} </a>
-                    '''.format(tag_uid=tag.tag_id,
-                               kind=postinfo.kind,
-                               tag_name=tag.tag_name,
-                               index=idx)
-                idx += 1
-            return outstr + '</span>'
-        return ''
+            outstr = self.join_tags(kind, tag_info)
+        else:
+            outstr = ''
+        return outstr
 
-
-class GetFooter(tornado.web.UIModule):
-    '''
-    Render footer.
-    '''
-    def render(self, *args, **kwargs):
-        logger.info('Init footer')
-        all_cats = MCategory.query_all()
-        kwd = {
-            'cats': all_cats,
-        }
-        return self.render_string('modules/post/menu.html', kwd=kwd)
+    def join_tags(self, kind, tag_info):
+        idx = 1
+        outstr = '<span class="post_label">'
+        tmpl_str = '<a href="/label/{kind}/{tag_uid}" class="app_label tag{index}">{tag_name}</a>'
+        for tag in tag_info:
+            outstr += tmpl_str.format(tag_uid=tag.tag_id,
+                                      kind=kind,
+                                      tag_name=tag.tag_name,
+                                      index=idx)
+            idx += 1
+        outstr = outstr + '</span>'
+        return outstr
 
 
 class PreviousPostLink(tornado.web.UIModule):
     '''
     Link for the previous post link.
     '''
+
     def render(self, *args, **kwargs):
         current_id = args[0]
         kind = kwargs.get("kind", '1')
@@ -120,6 +107,7 @@ class NextPostLink(tornado.web.UIModule):
     '''
     Link for the next post link.
     '''
+
     def render(self, *args, **kwargs):
         current_id = args[0]
         kind = kwargs.get("kind", '1')
@@ -137,12 +125,15 @@ class PostMostView(tornado.web.UIModule):
     '''
     list of most viewd posts.
     '''
-    def render(self, num, with_date=True, with_catalog=True, kind='1'):
+
+    def render(self, num, **kwargs):
+        kind = kwargs.get('kind', '1')
         kwd = {
-            'with_date': with_date,
-            'with_catalog': with_catalog,
-            'router': config.router_post['1'],
-            'kind': kind
+            'with_date': kwargs.get('with_date', True),
+            'with_catalog': kwargs.get('with_catalog', True),
+            'router': config.router_post[kind],
+            'kind': kind,
+            'glyph': kwargs.get('glyph', '')
         }
 
         return self.render_string('modules/post/post_list.html',
@@ -154,11 +145,12 @@ class PostRandom(tornado.web.UIModule):
     '''
     return some posts randomly.
     '''
+
     def render(self, num, with_date=True, with_catalog=True, kind='1'):
         kwd = {
             'with_date': with_date,
             'with_catalog': with_catalog,
-            'router': config.router_post['1']
+            'router': config.router_post[kind]
         }
         return self.render_string('modules/post/post_list.html',
                                   recs=MPost.query_random(num=num, kind=kind),
@@ -169,22 +161,26 @@ class PostCatRandom(tornado.web.UIModule):
     '''
     return some posts randomly of certain category.
     '''
+
     def render(self, cat_id, num, with_date=True, with_catalog=True):
         kwd = {
             'with_date': with_date,
             'with_catalog': with_catalog,
             'router': config.router_post['1'],
         }
-        return self.render_string('modules/post/post_list.html',
-                                  recs=MPost.query_cat_random(cat_id,
-                                                              limit=num),
-                                  kwd=kwd)
+        return self.render_string(
+            'modules/post/post_list.html',
+            recs=MPost.query_cat_random(cat_id,
+                                        limit=num),
+            kwd=kwd
+        )
 
 
 class PostRecentMostView(tornado.web.UIModule):
     '''
     return some posts most viewed recently.
     '''
+
     def render(self, num, recent, with_date=True, with_catalog=True):
         kwd = {
             'with_date': with_date,
@@ -200,6 +196,7 @@ class CategoryOf(tornado.web.UIModule):
     '''
     return the categories which uid starts with certain string.
     '''
+
     def render(self, *args, **kwargs):
         uid_with_str = args[0]
         return self.render_string(
@@ -211,29 +208,36 @@ class PostCategoryOf(tornado.web.UIModule):
     '''
     The catalog of the post.
     '''
-    def render(self,
-               uid_with_str,
-               slug=False,
-               order=False,
-               with_title=True,
-               glyph=''):
+
+    def render(self, uid_with_str, **kwargs):
         curinfo = MCategory.get_by_uid(uid_with_str)
         sub_cats = MCategory.query_sub_cat(uid_with_str)
-        kwd = {'glyph': glyph}
+        kind = kwargs.get('kind', '9')
+        slug = kwargs.get('slug', False)
+        cat_dic = []
+        for cat in sub_cats:
+            res = MPost.query_by_tag(cat.uid, kind)
+
+            if res.count() == 0:
+                pass
+            else:
+                cat_dic.append({cat.uid: cat.name})
+        kwd = {
+            'glyph': kwargs.get('glyph', ''),
+            'order': kwargs.get('order', False),
+            'with_title': kwargs.get('with_title', True),
+            'router': router_post[kind],
+            'kind': kind
+        }
         if slug:
             return self.render_string('modules/post/post_catalog_slug.html',
                                       pcatinfo=curinfo,
-                                      sub_cats=sub_cats,
                                       recs=sub_cats,
-                                      order=order,
-                                      with_title=with_title,
                                       kwd=kwd)
         else:
             return self.render_string('modules/info/catalog_of.html',
                                       pcatinfo=curinfo,
-                                      sub_cats=sub_cats,
-                                      recs=sub_cats,
-                                      with_title=with_title,
+                                      recs=cat_dic,
                                       kwd=kwd)
 
 
@@ -241,12 +245,15 @@ class PostRecent(tornado.web.UIModule):
     '''
     return the post of recent.
     '''
-    def render(self, num=10, with_catalog=True, with_date=True, kind='1'):
+
+    def render(self, num=10, **kwargs):
+        kind = kwargs.get('kind', '1')
         kwd = {
-            'with_date': with_date,
-            'with_catalog': with_catalog,
+            'with_date': kwargs.get('with_date', True),
+            'with_catalog': kwargs.get('with_catalog', True),
             'router': config.router_post[kind],
-            'kind': kind
+            'kind': kind,
+            'glyph': kwargs.get('glyph', '')
         }
         return self.render_string('modules/post/post_list.html',
                                   recs=MPost.query_recent(num, kind=kind),
@@ -257,16 +264,20 @@ class LinkList(tornado.web.UIModule):
     '''
     return the list of links.
     '''
+
     def render(self, *args, **kwargs):
         num = kwargs['num'] if 'num' in kwargs else 10
-        return self.render_string('modules/post/link_list.html',
-                                  recs=MLink.query_link(num))
+        return self.render_string(
+            'modules/post/link_list.html',
+            recs=MLink.query_link(num)
+        )
 
 
 class PostCategoryRecent(tornado.web.UIModule):
     '''
     The reccent posts of certain category.
     '''
+
     def render(self, *args, **kwargs):
 
         cat_id = args[0]
@@ -278,6 +289,7 @@ class PostCategoryRecent(tornado.web.UIModule):
 
         is_spa = kwargs.get('spa', False)
         order = kwargs.get('order', False)
+        post_uid = kwargs.get('post_uid', '')
 
         catinfo = MCategory.get_by_uid(cat_id)
         if catinfo.pid == '0000':
@@ -303,7 +315,8 @@ class PostCategoryRecent(tornado.web.UIModule):
             'glyph': glyph,
             'spa': is_spa,
             'order': order,
-            'kind': catinfo.kind
+            'kind': catinfo.kind,
+            'post_uid': post_uid
         }
         return self.render_string('modules/post/post_list.html',
                                   recs=recs,
@@ -314,6 +327,7 @@ class ShowoutRecent(tornado.web.UIModule):
     '''
     return posts of recent for showing out.
     '''
+
     def render(self, cat_id, kind, **kwargs):
         num = kwargs.get('num', 10)
 
@@ -340,6 +354,7 @@ class SiteUrl(tornado.web.UIModule):
     '''
     return the url of the site.
     '''
+
     def render(self, *args, **kwargs):
         return config.SITE_CFG['site_url']
 
@@ -348,6 +363,7 @@ class SiteTitle(tornado.web.UIModule):
     '''
     return the title of the site.
     '''
+
     def render(self, *args, **kwargs):
         if 'site_title' in config.SITE_CFG:
             return config.SITE_CFG['site_title']
@@ -359,6 +375,7 @@ class TheCategory(tornado.web.UIModule):
     '''
     return the category according to the id of post.
     '''
+
     def render(self, post_id, order=False):
         if order:
             tmpl_str = '''<a href="/catalog/{0}">{1}</a>'''
@@ -376,6 +393,7 @@ class ListCategories(tornado.web.UIModule):
     '''
     list categories.
     '''
+
     def render(self, cat_id, list_num):
         recs = MPost.query_cat_recent(cat_id, num=list_num)
         out_str = ''
@@ -390,6 +408,7 @@ class GenerateAbstract(tornado.web.UIModule):
     '''
     translate html to text, and return 130 charactors.
     '''
+
     def render(self, *args, **kwargs):
         html_str = args[0]
         count = kwargs.get('count', 130)
@@ -398,31 +417,23 @@ class GenerateAbstract(tornado.web.UIModule):
         return tmp_str.get_text()[:count] + '...'
 
 
-# Todo: should be deleted.
-class GenerateDescription(tornado.web.UIModule):
-    '''
-    Just as GenerateAbstract
-    '''
-    def render(self, *args, **kwargs):
-        html_str = args[0]
-        tmp_str = bs4.BeautifulSoup(tornado.escape.xhtml_unescape(html_str),
-                                    "html.parser")
-        return tmp_str.get_text()[:100]
-
-
-class CopyRight(tornado.web.UIModule):
-    '''
-    show TorCMS copy right.
-    '''
-    def render(self, *args, **kwargs):
-        return '''<span>Build on
-        <a href="https://github.com/bukun/TorCMS" target="_blank">TorCMS</a>.</span>'''
+# class GenerateDescription(tornado.web.UIModule):
+#     '''
+#     Just as GenerateAbstract
+#     '''
+#
+#     def render(self, *args, **kwargs):
+#         html_str = args[0]
+#         tmp_str = bs4.BeautifulSoup(tornado.escape.xhtml_unescape(html_str),
+#                                     "html.parser")
+#         return tmp_str.get_text()[:100]
 
 
 class PostTags(tornado.web.UIModule):
     '''
     show tags of the post.
     '''
+
     def render(self, *args, **kwargs):
         uid = args[0]
         kind = args[1]
@@ -441,6 +452,7 @@ class MapTags(tornado.web.UIModule):
     '''
     show tags of the map.
     '''
+
     def render(self, *args, **kwargs):
         uid = args[0]
         out_str = ''
@@ -454,30 +466,11 @@ class MapTags(tornado.web.UIModule):
         return out_str
 
 
-class ModuleCatMenu(tornado.web.UIModule):
-    '''
-
-    '''
-    def render(self, with_count=True):
-        kwd = {
-            'cats': MCategory.query_all(by_count=True),
-            'with_count': with_count,
-        }
-        return self.render_string('modules/post/menu_post.html', kwd=kwd)
-
-
-class ToplineModule(tornado.web.UIModule):
-    '''
-
-    '''
-    def render(self, *args, **kwargs):
-        return self.render_string('modules/widget/topline.html')
-
-
 class CategoryPager(tornado.web.UIModule):
     '''
     pager of category
     '''
+
     def render(self, *args, **kwargs):
         cat_slug = args[0]
         current = int(args[1])
@@ -492,16 +485,11 @@ class CategoryPager(tornado.web.UIModule):
         pager_cnt = int(num_of_cat / config.CMS_CFG['list_num'])
 
         page_num = (pager_cnt
-                    if abs(pager_cnt - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else pager_cnt + 1)
+                    if abs(pager_cnt - num_of_cat / config.CMS_CFG['list_num']) < 0.1
+                    else pager_cnt + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-            'tag': tag,
-        }
+        kwd = get_page_position(current, page_num)
+        kwd['tag'] = tag
 
         return self.render_string('modules/post/catalog_pager.html',
                                   kwd=kwd,
@@ -514,6 +502,7 @@ class CollectPager(tornado.web.UIModule):
     '''
     pager of category
     '''
+
     def render(self, *args, **kwargs):
         user_id = args[0]
         current = int(args[1])
@@ -524,16 +513,11 @@ class CollectPager(tornado.web.UIModule):
 
         pager_count = int(the_count / config.CMS_CFG['list_num'])
 
-        page_num = (pager_count if
-                    abs(pager_count - the_count / config.CMS_CFG['list_num']) <
-                    0.1 else pager_count + 1)
+        page_num = (pager_count
+                    if abs(pager_count - the_count / config.CMS_CFG['list_num']) < 0.1
+                    else pager_count + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/collect_pager.html',
                                   kwd=kwd,
@@ -545,6 +529,7 @@ class InfoLabelPager(tornado.web.UIModule):
     '''
     Pager for info label.
     '''
+
     def render(self, *args, **kwargs):
         tag_slug = args[0]
         current = int(args[1])
@@ -553,16 +538,10 @@ class InfoLabelPager(tornado.web.UIModule):
 
         pager_count = int(cat_rec.count() / config.CMS_CFG['list_num'])
         page_num = (pager_count
-                    if abs(pager_count -
-                           cat_rec.count() / config.CMS_CFG['list_num']) < 0.1
+                    if abs(pager_count - cat_rec.count() / config.CMS_CFG['list_num']) < 0.1
                     else pager_count + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/info_label_pager.html',
                                   kwd=kwd,
@@ -575,6 +554,7 @@ class LabelPager(tornado.web.UIModule):
     '''
     Pager for label.
     '''
+
     def render(self, *args, **kwargs):
         kind = args[0]
         tag_slug = args[1]
@@ -585,14 +565,10 @@ class LabelPager(tornado.web.UIModule):
             config.CMS_CFG['list_num'])
         page_num = (
             pager_count
-            if abs(pager_count - MPost2Label.total_number(tag_slug, kind) /
-                   config.CMS_CFG['list_num']) < 0.1 else pager_count + 1)
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+            if abs(pager_count - MPost2Label.total_number(tag_slug, kind) / config.CMS_CFG['list_num']) < 0.1
+            else pager_count + 1
+        )
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/label_pager.html',
                                   kwd=kwd,
@@ -606,22 +582,18 @@ class TagPager(tornado.web.UIModule):
     '''
     Pager for tag.
     '''
+
     def render(self, *args, **kwargs):
         tag_slug = args[0]
         current = int(args[1])
         taginfo = MCategory.get_by_slug(tag_slug)
         num_of_tag = MPost2Catalog.count_of_certain_category(taginfo.uid)
         pager_count = int(math_ceil(num_of_tag / config.CMS_CFG['list_num']))
-        page_num = (pager_count if
-                    abs(pager_count - num_of_tag / config.CMS_CFG['list_num'])
-                    < 0.1 else pager_count + 1)
+        page_num = (pager_count
+                    if abs(pager_count - num_of_tag / config.CMS_CFG['list_num']) < 0.1
+                    else pager_count + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/tag_pager.html',
                                   kwd=kwd,
@@ -634,6 +606,7 @@ class SearchPager(tornado.web.UIModule):
     '''
     Pager for search result.
     '''
+
     def render(self, *args, **kwargs):
         ysearch = YunSearch()
         catid = args[0]
@@ -641,15 +614,8 @@ class SearchPager(tornado.web.UIModule):
         current = int(args[2])
         res_all = ysearch.get_all_num(tag_slug, catid=catid)
         pager_count = int(res_all / config.CMS_CFG['list_num'])
-        page_num = (pager_count
-                    if abs(pager_count - res_all / config.CMS_CFG['list_num'])
-                    < 0.1 else pager_count + 1)
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        page_num = pager_count if abs(pager_count - res_all / config.CMS_CFG['list_num']) < 0.1 else pager_count + 1
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/search_pager.html',
                                   kwd=kwd,
@@ -663,16 +629,20 @@ class AppTitle(tornado.web.UIModule):
     '''
     search widget. Simple searching. searching for all.
     '''
+
     def render(self, *args, **kwargs):
         uid = args[0]
         rec = MPost.get_by_uid(uid=uid)
-        return rec.title if rec else None
+
+        return self.render_string('modules/info/app_title.html',
+                                  rec=rec)
 
 
 class EntityList(tornado.web.UIModule):
     '''
     search widget. Simple searching. searching for all.
     '''
+
     def render(self, kind, cur_p=''):
         if cur_p == '':
             current_page_number = 1
@@ -694,19 +664,15 @@ class EntityPager(tornado.web.UIModule):
     '''
     Pager for search result.
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
 
         pager_count = int(MEntity.total_number() / config.CMS_CFG['list_num'])
-        page_num = (pager_count if abs(pager_count - MEntity.total_number() /
-                                       config.CMS_CFG['list_num']) < 0.1 else
-                    pager_count + 1)
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        page_num = (pager_count
+                    if abs(pager_count - MEntity.total_number() / config.CMS_CFG['list_num']) < 0.1
+                    else pager_count + 1)
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/entity_pager.html',
                                   kwd=kwd,
@@ -718,6 +684,7 @@ class Entity2UserPager(tornado.web.UIModule):
     '''
     Pager for search result.
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
         user_id = kwargs.get('userid', None)
@@ -725,16 +692,10 @@ class Entity2UserPager(tornado.web.UIModule):
         pager_count = int(
             MEntity2User.total_number_by_user(user_id) /
             config.CMS_CFG['list_num'])
-        page_num = (
-            pager_count
-            if abs(pager_count - MEntity2User.total_number_by_user(user_id) /
-                   config.CMS_CFG['list_num']) < 0.1 else pager_count + 1)
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        page_num = (pager_count
+                    if abs(pager_count - MEntity2User.total_number_by_user(user_id) / config.CMS_CFG['list_num']) < 0.1
+                    else pager_count + 1)
+        kwd = get_page_position(current, page_num)
 
         return self.render_string(
             'modules/post/entity_user_download_pager.html',
@@ -748,21 +709,17 @@ class Entity2Pager(tornado.web.UIModule):
     '''
     Pager for search result.
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
         user_id = kwargs.get('userid', None)
 
         pager_count = int(MEntity2User.total_number() /
                           config.CMS_CFG['list_num'])
-        page_num = (pager_count if
-                    abs(pager_count - MEntity2User.total_number() /
-                        config.CMS_CFG['list_num']) < 0.1 else pager_count + 1)
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        page_num = (pager_count
+                    if abs(pager_count - MEntity2User.total_number() / config.CMS_CFG['list_num']) < 0.1
+                    else pager_count + 1)
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/entity_download_pager.html',
                                   kwd=kwd,
@@ -771,22 +728,11 @@ class Entity2Pager(tornado.web.UIModule):
                                   page_current=current)
 
 
-# class Entity_path(tornado.web.UIModule):
-#     '''
-#     Pager for search result.
-#     '''
-#
-#     def render(self, enti_id):
-#         rec = MEntity.get_by_uid(enti_id)
-#
-#         return self.render_string('modules/post/entity_path.html',
-#                                   rec=rec)
-
-
 class UserName(tornado.web.UIModule):
     '''
     Pager for search result.
     '''
+
     def render(self, *args, **kwargs):
         user_id = args[0]
         rec = MUser.get_by_uid(user_id)
@@ -798,6 +744,7 @@ class ReplyPostById(tornado.web.UIModule):
     '''
     Pager for search result.
     '''
+
     def render(self, post_id, reply_uid):
         try:
             rec = MPost.get_by_uid(post_id)
@@ -813,6 +760,7 @@ class CategoryBySlug(tornado.web.UIModule):
     '''
     catalog 列表页 面包屑导航
     '''
+
     def render(self, *args, **kwargs):
         slug = args[0]
         rec = MCategory.get_by_slug(slug)
@@ -829,20 +777,24 @@ class CategoryBySlug(tornado.web.UIModule):
 
 class Collect(tornado.web.UIModule):
     '''
-添加收藏模块
+    添加收藏模块
     '''
+
     def render(self, *args, **kwargs):
         user_id = args[0]
         post_id = args[1]
+        en = kwargs.get('en', False)
         user_collect = MCollect.get_by_signature(user_id, post_id)
         return self.render_string('modules/widget/collect.html',
-                                  user_collect=user_collect)
+                                  user_collect=user_collect,
+                                  en=en)
 
 
 class UserCollect(tornado.web.UIModule):
     '''
     用户收藏列表
     '''
+
     def render(self, *args, **kwargs):
         user_id = kwargs.get('user_id', args[0])
         kind = kwargs.get('kind', args[1])
@@ -861,6 +813,7 @@ class Admin_Post_pager(tornado.web.UIModule):
     '''
     pager of kind
     '''
+
     def render(self, *args, **kwargs):
         kind = args[0]
         current = int(args[1])
@@ -871,16 +824,11 @@ class Admin_Post_pager(tornado.web.UIModule):
 
         tmp_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
 
-        page_num = (tmp_page_num if
-                    abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else tmp_page_num + 1)
+        page_num = (tmp_page_num
+                    if abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num']) < 0.1
+                    else tmp_page_num + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/admin/post_pager.html',
                                   kwd=kwd,
@@ -893,6 +841,7 @@ class Admin_Page_pager(tornado.web.UIModule):
     '''
     pager of kind
     '''
+
     def render(self, *args, **kwargs):
         kind = args[0]
         current = int(args[1])
@@ -903,16 +852,11 @@ class Admin_Page_pager(tornado.web.UIModule):
 
         tmp_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
 
-        page_num = (tmp_page_num if
-                    abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else tmp_page_num + 1)
+        page_num = (tmp_page_num
+                    if abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num']) < 0.1
+                    else tmp_page_num + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/admin/page_pager.html',
                                   kwd=kwd,
@@ -925,6 +869,7 @@ class Admin_reply_pager(tornado.web.UIModule):
     '''
     pager of kind
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
         # kind
@@ -932,18 +877,20 @@ class Admin_reply_pager(tornado.web.UIModule):
 
         num_of_cat = MReply.count_of_certain()
 
-        tmp_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
+        test_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
 
-        page_num = (tmp_page_num if
-                    abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else tmp_page_num + 1)
+        '''
+        原代码：
+        page_num = (test_page_num if
+                    abs(test_page_num - num_of_cat / config.CMS_CFG['list_num'])
+                    < 0.1 else test_page_num + 1)
+        '''
+        if abs(test_page_num - num_of_cat / config.CMS_CFG['list_num']) < 0.1:
+            page_num = test_page_num
+        else:
+            page_num = test_page_num + 1
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/admin/reply_pager.html',
                                   kwd=kwd,
@@ -955,6 +902,7 @@ class Admin_user_pager(tornado.web.UIModule):
     '''
     pager of kind
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
         # kind
@@ -964,16 +912,11 @@ class Admin_user_pager(tornado.web.UIModule):
 
         tmp_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
 
-        page_num = (tmp_page_num if
-                    abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else tmp_page_num + 1)
+        page_num = (tmp_page_num
+                    if abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num']) < 0.1
+                    else tmp_page_num + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/admin/user_pager.html',
                                   kwd=kwd,
@@ -981,10 +924,23 @@ class Admin_user_pager(tornado.web.UIModule):
                                   page_current=current)
 
 
+def get_page_position(current, page_num):
+    '''
+    返回当面页面索引位置信息
+    '''
+    return {
+        'page_home': current > 1,
+        'page_end': current < page_num,
+        'page_pre': current > 1,
+        'page_next': current < page_num,
+    }
+
+
 class Admin_log_pager(tornado.web.UIModule):
     '''
     pager of log
     '''
+
     def render(self, *args, **kwargs):
         user_id = args[0]
         current = int(args[1])
@@ -995,16 +951,11 @@ class Admin_log_pager(tornado.web.UIModule):
 
         tmp_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
 
-        page_num = (tmp_page_num if
-                    abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else tmp_page_num + 1)
+        page_num = (tmp_page_num
+                    if abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num']) < 0.1
+                    else tmp_page_num + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/admin/log_admin_pager.html',
                                   kwd=kwd,
@@ -1017,6 +968,7 @@ class LogPager(tornado.web.UIModule):
     '''
     pager of log
     '''
+
     def render(self, *args, **kwargs):
         user_id = args[0]
         current = int(args[1])
@@ -1025,16 +977,11 @@ class LogPager(tornado.web.UIModule):
 
         pager_count = int(the_count / config.CMS_CFG['list_num'])
 
-        page_num = (pager_count if
-                    abs(pager_count - the_count / config.CMS_CFG['list_num']) <
-                    0.1 else pager_count + 1)
+        page_num = (pager_count
+                    if abs(pager_count - the_count / config.CMS_CFG['list_num']) < 0.1
+                    else pager_count + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/admin/log_pager.html',
                                   kwd=kwd,
@@ -1047,6 +994,7 @@ class LogPageviewPager(tornado.web.UIModule):
     '''
     pager of log
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
 
@@ -1054,16 +1002,11 @@ class LogPageviewPager(tornado.web.UIModule):
 
         pager_count = int(the_count / config.CMS_CFG['list_num'])
 
-        page_num = (pager_count if
-                    abs(pager_count - the_count / config.CMS_CFG['list_num']) <
-                    0.1 else pager_count + 1)
+        page_num = (pager_count
+                    if abs(pager_count - the_count / config.CMS_CFG['list_num']) < 0.1
+                    else pager_count + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/admin/log_pageview_pager.html',
                                   kwd=kwd,
@@ -1084,6 +1027,7 @@ class InfoNullify(tornado.web.UIModule):
     '''
     将信息变为无效module
     '''
+
     def render(self, *args, **kwargs):
         info_uid = kwargs.get('uid', '')
         info_router = kwargs.get('router', '')
@@ -1097,8 +1041,9 @@ class InfoNullify(tornado.web.UIModule):
 
 class Nullify_pager(tornado.web.UIModule):
     '''
-   无效信息列表分页
+    无效信息列表分页
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
 
@@ -1106,16 +1051,11 @@ class Nullify_pager(tornado.web.UIModule):
 
         tmp_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
 
-        page_num = (tmp_page_num if
-                    abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else tmp_page_num + 1)
+        page_num = (tmp_page_num
+                    if abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num']) < 0.1
+                    else tmp_page_num + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/nullify_pager.html',
                                   kwd=kwd,
@@ -1127,6 +1067,7 @@ class Comment_pager(tornado.web.UIModule):
     '''
     pager of Comment
     '''
+
     def render(self, *args, **kwargs):
         current = int(args[0])
 
@@ -1134,16 +1075,11 @@ class Comment_pager(tornado.web.UIModule):
 
         tmp_page_num = int(num_of_cat / config.CMS_CFG['list_num'])
 
-        page_num = (tmp_page_num if
-                    abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num'])
-                    < 0.1 else tmp_page_num + 1)
+        page_num = (tmp_page_num
+                    if abs(tmp_page_num - num_of_cat / config.CMS_CFG['list_num']) < 0.1
+                    else tmp_page_num + 1)
 
-        kwd = {
-            'page_home': False if current <= 1 else True,
-            'page_end': False if current >= page_num else True,
-            'page_pre': False if current <= 1 else True,
-            'page_next': False if current >= page_num else True,
-        }
+        kwd = get_page_position(current, page_num)
 
         return self.render_string('modules/post/comment_pager.html',
                                   kwd=kwd,
@@ -1155,6 +1091,7 @@ class Comment_num(tornado.web.UIModule):
     '''
     num of Comment
     '''
+
     def render(self, *args, **kwargs):
         postid = args[0]
         comment_num = MComment.count_of_comment(postid)
