@@ -37,7 +37,7 @@ class InfoCategory(tornado.web.UIModule):
         glyph = kwargs.get('glyph', '')
         count = kwargs.get('count', False)
 
-        kwd = {'glyph': glyph, 'count': count}
+        kwd = {'glyph': glyph, 'count': count, 'with_title': with_title}
         curinfo = MCategory.get_by_uid(uid_with_str)
 
         sub_cats = MCategory.query_sub_cat(uid_with_str)
@@ -338,6 +338,22 @@ class InfoCount(tornado.web.UIModule):
         return recs.count()
 
 
+class InfoCountByState(tornado.web.UIModule):
+    '''
+    各信息分类下，信息数量。
+    '''
+
+    def render(self, *args, **kwargs):
+        pcat = kwargs['pcat']
+        catid = kwargs['catid']
+        kind = kwargs['kind']
+        if pcat:
+            recs = MPost.query_by_parid(catid, kind)
+        else:
+            recs = MPost.query_by_tag(catid, kind)
+        return recs.count()
+
+
 class InfoMenu(tornado.web.UIModule):
     '''
     menu for infor.
@@ -417,73 +433,6 @@ class RelApp2post(tornado.web.UIModule):
                                   kwd=kwd)
 
 
-class ImgSlide(tornado.web.UIModule):
-    '''
-    Module for Image slide.
-    fun(info)
-    '''
-
-    def render(self, *args, **kwargs):
-        info = kwargs.get('info', args[0])
-        return self.render_string('modules/info/img_slide.html',
-                                  post_info=info)
-
-
-class UserInfo(tornado.web.UIModule):
-    '''
-    Display userinfo.
-    fun(uinfo, uop)
-    '''
-
-    def render(self, *args, **kwargs):
-        uinfo = kwargs.get('uinfo', args[0])
-        uop = kwargs.get('uop', args[1])
-        return self.render_string('modules/info/user_info.html',
-                                  userinfo=uinfo,
-                                  userop=uop)
-
-
-class VipInfo(tornado.web.UIModule):
-    '''
-    VipInfo
-    fun(uinfo, uvip)
-    '''
-
-    def render(self, *args, **kwargs):
-        uinfo = kwargs.get('uinfo', args[0])
-        uvip = kwargs.get('uvip', args[1])
-        return self.render_string('modules/info/vip_info.html',
-                                  userinfo=uinfo,
-                                  uservip=uvip)
-
-
-class BannerModule(tornado.web.UIModule):
-    '''
-    BannerModule
-    fun(parentid = val)
-    '''
-
-    def render(self, *args, **kwargs):
-        parentid = kwargs.get('parentid', '')
-        parentlist = MCategory.get_parent_list()
-        kwd = {
-            'parentlist': parentlist,
-            'parentid': parentid,
-        }
-        return self.render_string('modules/info/banner.html', kwd=kwd)
-
-
-class BreadCrumb(tornado.web.UIModule):
-    '''
-    BreadCrumb
-    fun(info)
-    '''
-
-    def render(self, *args, **kwargs):
-        info = kwargs.get('info', args[0])
-        return self.render_string('modules/info/bread_crumb.html', info=info)
-
-
 class ParentName(tornado.web.UIModule):
     '''
     ParentName
@@ -506,24 +455,6 @@ class CatName(tornado.web.UIModule):
         return self.render_string('modules/info/catname.html', info=info)
 
 
-class ContactInfo(tornado.web.UIModule):
-    '''
-    ContactInfo
-    fun(info)
-    '''
-
-    def render(self, *args, **kwargs):
-        # info = args[0]
-
-        info = kwargs.get('info', args[0])
-        kwd = {
-            'maskip': '',  # maskip,
-        }
-        return self.render_string('modules/info/contact_info.html',
-                                  post_info=info,
-                                  kwd=kwd)
-
-
 class BreadcrumbPublish(tornado.web.UIModule):
     '''
     BreadCrumb
