@@ -7,8 +7,6 @@ from torcms.modules import (base_modules, catalog_modules, category_modules,
                             info_modules, widget_modules)
 
 core_modules = {
-    'ModuleCatMenu': base_modules.ModuleCatMenu,
-    'get_footer': base_modules.GetFooter,
     'previous_post_link': base_modules.PreviousPostLink,
     'next_post_link': base_modules.NextPostLink,
     'the_category': base_modules.TheCategory,
@@ -25,7 +23,7 @@ core_modules = {
     'generate_abstract': base_modules.GenerateAbstract,
     'site_url': base_modules.SiteUrl,
     'site_title': base_modules.SiteTitle,
-    'generate_description': base_modules.GenerateDescription,
+    # 'generate_description': base_modules.GenerateDescription,
     'post_tags': base_modules.PostTags,
     'post_catalogs': base_modules.PostTags,
     'map_catalogs': base_modules.MapTags,
@@ -41,10 +39,8 @@ core_modules = {
     'catalog_of': base_modules.CategoryOf,
     'post_catalog_of': base_modules.PostCategoryOf,
     'show_page': base_modules.ShowPage,
-    'Topline': base_modules.ToplineModule,
     'collect': base_modules.Collect,
     'user_collect': base_modules.UserCollect,
-    'torcms_copyright': base_modules.CopyRight,
     'entity_list': base_modules.EntityList,
     'entity_pager': base_modules.EntityPager,
     'entity_download_user': base_modules.Entity2UserPager,
@@ -53,7 +49,6 @@ core_modules = {
     'user_name_by_id': base_modules.UserName,
     'reply_post_by_id': base_modules.ReplyPostById,
     'category_by_slug': base_modules.CategoryBySlug,
-    'postlistoftag': base_modules.PostListOfTag,
     'admin_post_pager': base_modules.Admin_Post_pager,
     'admin_page_pager': base_modules.Admin_Page_pager,
     'admin_reply_pager': base_modules.Admin_reply_pager,
@@ -76,19 +71,12 @@ core_modules = {
     'upload_pic': widget_modules.UploadPicture,
     'upload_file': widget_modules.UploadFile,
     'nav_menu': widget_modules.Navigation_menu,
-    'baidu_search': widget_modules.BaiduSearch,
 
     # Infor
     'app_catalog_of': info_modules.InfoCategory,
-    'Banner': info_modules.BannerModule,
-    'BreadCrumb': info_modules.BreadCrumb,
     'parentname': info_modules.ParentName,
     'catname': info_modules.CatName,
-    'ContactInfo': info_modules.ContactInfo,
     'BreadcrumbPublish': info_modules.BreadcrumbPublish,
-    'ImgSlide': info_modules.ImgSlide,
-    'user_info': info_modules.UserInfo,
-    'vip_info': info_modules.VipInfo,
     'rel_post2app': info_modules.RelPost2app,
     'rel_app2post': info_modules.RelApp2post,
     'app_random_choose': info_modules.InfoRandom,
@@ -113,4 +101,7 @@ core_modules = {
     'comment_list': widget_modules.CommentList,
     'replycnt': widget_modules.Replycnt,
     'user_profile_by_id': widget_modules.Userprofile,
+    'post_state': widget_modules.State,
+    'check_pager': widget_modules.Check_pager,
+    'check_username_pager': widget_modules.Check_username_pager
 }
