@@ -9,13 +9,13 @@ import sys
 
 from openpyxl.reader.excel import load_workbook
 
-from .base_crud import FILTER_COLUMNS, INPUT_ARR, XLSX_FILE
+from .base_crud import FILTER_COLUMNS, INPUT_ARR, XLSX_FILE_LIST
 
-if os.path.exists(XLSX_FILE):
-    WORK_BOOK = load_workbook(filename=XLSX_FILE)
-else:
-    print('There must be at least one XLSX file.')
-    sys.exit(0)
+# if os.path.exists(XLSX_FILE):
+#     WORK_BOOK = load_workbook(filename=XLSX_FILE)
+# else:
+#     print('There must be at least one XLSX file.')
+#     sys.exit(0)
 
 
 def __write_filter_dic(wk_sheet, column):
@@ -72,17 +72,25 @@ def gen_html_dic():
     生成 Filter .
     '''
 
-    if WORK_BOOK:
-        pass
-    else:
-        return False
-
     html_dics = {}
-    for wk_sheet in WORK_BOOK:
-        for column in FILTER_COLUMNS:
-            kkey, kval = __write_filter_dic(wk_sheet, column)
-            if kkey:
-                html_dics[kkey] = kval
+
+    for XLSX_FILE in XLSX_FILE_LIST:
+        print(type(XLSX_FILE))
+        if XLSX_FILE.exists():
+            WORK_BOOK = load_workbook(filename=XLSX_FILE)
+        else:
+            continue
+        if WORK_BOOK:
+            pass
+        else:
+            return False
+
+
+        for wk_sheet in WORK_BOOK:
+            for column in FILTER_COLUMNS:
+                kkey, kval = __write_filter_dic(wk_sheet, column)
+                if kkey:
+                    html_dics[kkey] = kval
 
     return html_dics
 
@@ -92,43 +100,49 @@ def gen_array_crud():
     Return the dictionay of the switcher form XLXS file.
     if valud of the column of the row is `1`,  it will be added to the array.
     '''
-    if WORK_BOOK:
-        pass
-    else:
-        return False
-
-    papa_id = 0
-
     switch_dics = {}
     kind_dics = {}
 
-    for work_sheet in WORK_BOOK:
-        kind_sig = str(work_sheet['A1'].value).strip()
-        # the number of the categories in a website won't greater than 1000.
-        for row_num in range(3, 1000):
-            # 父类, column A
-            a_cell_value = work_sheet['A{0}'.format(row_num)].value
-            # 子类, column B
-            b_cell_val = work_sheet['B{0}'.format(row_num)].value
+    for XLSX_FILE in XLSX_FILE_LIST:
+        if XLSX_FILE.exists():
+            WORK_BOOK = load_workbook(filename=XLSX_FILE)
+        else:
+            continue
+        if WORK_BOOK:
+            pass
+        else:
+            return False
 
-            if a_cell_value or b_cell_val:
-                pass
-            else:
-                break
-            if a_cell_value and a_cell_value != '':
-                papa_id = a_cell_value.strip()[1:]
-                u_dic = __get_switch_arr(work_sheet, row_num)
-                switch_dics['dic_{0}00'.format(papa_id)] = u_dic
-                kind_dics['kind_{0}00'.format(papa_id)] = kind_sig
-            if b_cell_val and b_cell_val != '':
-                sun_id = b_cell_val.strip()[1:]
-                if len(sun_id) == 4:
-                    app_uid = sun_id
+        papa_id = 0
+
+
+        for work_sheet in WORK_BOOK:
+            kind_sig = str(work_sheet['A1'].value).strip()
+            # the number of the categories in a website won't greater than 1000.
+            for row_num in range(3, 1000):
+                # 父类, column A
+                a_cell_value = work_sheet['A{0}'.format(row_num)].value
+                # 子类, column B
+                b_cell_val = work_sheet['B{0}'.format(row_num)].value
+
+                if a_cell_value or b_cell_val:
+                    pass
                 else:
-                    app_uid = '{0}{1}'.format(papa_id, sun_id)
-                u_dic = __get_switch_arr(work_sheet, row_num)
-                switch_dics['dic_{0}'.format(app_uid)] = u_dic
-                kind_dics['kind_{0}'.format(app_uid)] = kind_sig
+                    break
+                if a_cell_value and a_cell_value != '':
+                    papa_id = a_cell_value.strip()[1:]
+                    u_dic = __get_switch_arr(work_sheet, row_num)
+                    switch_dics['dic_{0}00'.format(papa_id)] = u_dic
+                    kind_dics['kind_{0}00'.format(papa_id)] = kind_sig
+                if b_cell_val and b_cell_val != '':
+                    sun_id = b_cell_val.strip()[1:]
+                    if len(sun_id) == 4:
+                        app_uid = sun_id
+                    else:
+                        app_uid = '{0}{1}'.format(papa_id, sun_id)
+                    u_dic = __get_switch_arr(work_sheet, row_num)
+                    switch_dics['dic_{0}'.format(app_uid)] = u_dic
+                    kind_dics['kind_{0}'.format(app_uid)] = kind_sig
 
     return (switch_dics, kind_dics)
 
