@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
-
 '''
-initialize table.s
+删除所有的表。
 '''
 
-from torcms.model.core_tab import TabPost, TabTag, TabMember, TabWiki, TabLink, TabEntity, \
-    TabPostHist, TabWikiHist, TabCollect, TabPost2Tag, TabRel, TabEvaluation, TabUsage, TabReply, \
-    TabUser2Reply, TabRating,TabLog,TabReferrer,TabEntity2User,TabReplyid
+from torcms.model.core_tab import (TabCollect, TabEntity, TabEntity2User,
+                                   TabEvaluation, TabLink, TabLog, TabMember,
+                                   TabPost, TabPost2Tag, TabPostHist,
+                                   TabRating, TabReferrer, TabRel, TabReply,
+                                   TabReplyid, TabTag, TabUsage, TabUser2Reply,
+                                   TabWiki, TabWikiHist, TabCorrelation)
 
 
 def drop_the_table(table_name):
@@ -15,8 +17,8 @@ def drop_the_table(table_name):
     '''
     try:
         table_name.drop_table()
-    except:
-        pass
+    except Exception as err:
+        print(repr(err))
 
 
 def run_drop_tables(_):
@@ -45,3 +47,4 @@ def run_drop_tables(_):
     drop_the_table(TabReferrer)
     drop_the_table(TabEntity2User)
     drop_the_table(TabReplyid)
+    drop_the_table(TabCorrelation)
