@@ -37,7 +37,7 @@ def run_create_admin(*args):
     post_data = {
         'user_name': 'admin',
         'user_email': 'admin@osgeo.cn',
-        'user_pass': '01234567',
+        'user_pass': 'Gg01234567',
         'role': '3300',
     }
     if MUser.get_by_name(post_data['user_name']):
